>From bc714222cd994de754c84b4251af6862c774b40e Mon Sep 17 00:00:00 2001
From: Erik Van Grunderbeeck <erik@arawix.com>
Date: Tue, 22 Mar 2011 10:33:58 +0100
Subject: [PATCH] Clean up debugging macro's, make debugging intel compiler compatible. Rename some defines that are more or less considered standard for some development environments (TRACE, DEBUG, ERROR)

Signed-off-by: Erik Van Grunderbeeck <erik@arawix.com>
---
 src/file/dir_posix.c                         |    6 +-
 src/file/dl_posix.c                          |   10 +-
 src/file/file_posix.c                        |    6 +-
 src/libbluray/bdj/bdj.c                      |   12 +-
 src/libbluray/bdj/bdjo_parser.c              |   10 +-
 src/libbluray/bdnav/index_parse.c            |   12 +-
 src/libbluray/bdnav/meta_parse.c             |   16 ++--
 src/libbluray/bdnav/navigation.c             |    8 +-
 src/libbluray/bdnav/sound_parse.c            |   18 ++--
 src/libbluray/bluray.c                       |  132 +++++++++++++-------------
 src/libbluray/decoders/graphics_controller.c |   69 +++++++-------
 src/libbluray/decoders/graphics_processor.c  |   16 +--
 src/libbluray/decoders/ig_decode.c           |   11 +--
 src/libbluray/decoders/m2ts_demux.c          |   25 ++---
 src/libbluray/decoders/pg_decode.c           |   15 +--
 src/libbluray/hdmv/hdmv_vm.c                 |   90 +++++++++---------
 src/libbluray/hdmv/mobj_parse.c              |    8 +-
 src/libbluray/register.c                     |   16 ++--
 src/util/logging.c                           |    4 +-
 src/util/logging.h                           |   10 ++-
 src/util/mutex.h                             |   10 +-
 21 files changed, 248 insertions(+), 256 deletions(-)

diff --git a/src/file/dir_posix.c b/src/file/dir_posix.c
index 0c473de..b9e76b3 100644
--- a/src/file/dir_posix.c
+++ b/src/file/dir_posix.c
@@ -53,7 +53,7 @@ static void dir_close_posix(BD_DIR_H *dir)
         closedir((DIR *)dir->internal);
 #endif
 
-        DEBUG(DBG_DIR, "Closed POSIX dir (%p)\n", dir);
+        BD_DEBUG(DBG_DIR, "Closed POSIX dir (%p)\n", dir);
 
         X_FREE(dir);
     }
@@ -92,7 +92,7 @@ static BD_DIR_H *dir_open_posix(const char* dirname)
 {
     BD_DIR_H *dir = malloc(sizeof(BD_DIR_H));
 
-    DEBUG(DBG_DIR, "Opening POSIX dir %s... (%p)\n", dirname, dir);
+    BD_DEBUG(DBG_DIR, "Opening POSIX dir %s... (%p)\n", dirname, dir);
     dir->close = dir_close_posix;
     dir->read = dir_read_posix;
 
@@ -122,7 +122,7 @@ static BD_DIR_H *dir_open_posix(const char* dirname)
     }
 #endif
 
-    DEBUG(DBG_DIR, "Error opening dir! (%p)\n", dir);
+    BD_DEBUG(DBG_DIR, "Error opening dir! (%p)\n", dir);
 
     X_FREE(dir);
 
diff --git a/src/file/dl_posix.c b/src/file/dl_posix.c
index 80fd193..57ab232 100644
--- a/src/file/dl_posix.c
+++ b/src/file/dl_posix.c
@@ -75,7 +75,7 @@ void   *dl_dlopen  ( const char* path, const char *version )
         name = str_printf("%s%s", path, ext);
     }
 
-    DEBUG(DBG_FILE, "searching for library '%s' ...\n", name);
+    BD_DEBUG(DBG_FILE, "searching for library '%s' ...\n", name);
 
 #if defined(_WIN32)
     wchar_t wname[MAX_PATH];
@@ -84,13 +84,13 @@ void   *dl_dlopen  ( const char* path, const char *version )
 
     if (!result) {
         char buf[128];
-        DEBUG(DBG_FILE, "can't open library '%s': %s\n", name, dlerror(buf, sizeof(buf)));
+        BD_DEBUG(DBG_FILE, "can't open library '%s': %s\n", name, dlerror(buf, sizeof(buf)));
     }
 #else
     result = dlopen(name, RTLD_LAZY);
 
     if (!result) {
-        DEBUG(DBG_FILE, "can't open library '%s': %s\n", name, dlerror());
+        BD_DEBUG(DBG_FILE, "can't open library '%s': %s\n", name, dlerror());
     }
 #endif
 
@@ -106,13 +106,13 @@ void   *dl_dlsym   ( void* handle, const char* symbol )
 
     if (!result) {
         char buf[128];
-        DEBUG(DBG_FILE | DBG_CRIT, "GetProcAddress(%p, '%s') failed: %s\n", handle, symbol, dlerror(buf, sizeof(buf)));
+        BD_DEBUG(DBG_FILE | DBG_CRIT, "GetProcAddress(%p, '%s') failed: %s\n", handle, symbol, dlerror(buf, sizeof(buf)));
     }
 #else
     void *result = dlsym(handle, symbol);
 
     if (!result) {
-        DEBUG(DBG_FILE | DBG_CRIT, "dlsym(%p, '%s') failed: %s\n", handle, symbol, dlerror());
+        BD_DEBUG(DBG_FILE | DBG_CRIT, "dlsym(%p, '%s') failed: %s\n", handle, symbol, dlerror());
     }
 #endif
 
diff --git a/src/file/file_posix.c b/src/file/file_posix.c
index 86ca59a..22b813f 100644
--- a/src/file/file_posix.c
+++ b/src/file/file_posix.c
@@ -39,7 +39,7 @@ static void file_close_linux(BD_FILE_H *file)
     if (file) {
         fclose((FILE *)file->internal);
 
-        DEBUG(DBG_FILE, "Closed LINUX file (%p)\n", file);
+        BD_DEBUG(DBG_FILE, "Closed LINUX file (%p)\n", file);
 
         X_FREE(file);
     }
@@ -83,7 +83,7 @@ static BD_FILE_H *file_open_linux(const char* filename, const char *mode)
     FILE *fp = NULL;
     BD_FILE_H *file = malloc(sizeof(BD_FILE_H));
 
-    DEBUG(DBG_FILE, "Opening LINUX file %s... (%p)\n", filename, file);
+    BD_DEBUG(DBG_FILE, "Opening LINUX file %s... (%p)\n", filename, file);
     file->close = file_close_linux;
     file->seek = file_seek_linux;
     file->read = file_read_linux;
@@ -97,7 +97,7 @@ static BD_FILE_H *file_open_linux(const char* filename, const char *mode)
         return file;
     }
 
-    DEBUG(DBG_FILE, "Error opening file! (%p)\n", file);
+    BD_DEBUG(DBG_FILE, "Error opening file! (%p)\n", file);
 
     X_FREE(file);
 
diff --git a/src/libbluray/bdj/bdj.c b/src/libbluray/bdj/bdj.c
index 9ab8c1a..58c0af7 100644
--- a/src/libbluray/bdj/bdj.c
+++ b/src/libbluray/bdj/bdj.c
@@ -44,7 +44,7 @@ BDJAVA* bdj_open(const char *path, const char* start, void* bd, void* registers)
     void* jvm_lib = load_jvm();
 
     if (!jvm_lib) {
-        DEBUG(DBG_BDJ | DBG_CRIT, "Wasn't able to load libjvm.so\n");
+        BD_DEBUG(DBG_BDJ | DBG_CRIT, "Wasn't able to load libjvm.so\n");
         return NULL;
     }
 
@@ -77,7 +77,7 @@ BDJAVA* bdj_open(const char *path, const char* start, void* bd, void* registers)
         free(bdjava);
         free(option);
         free(classpath_opt);
-        DEBUG(DBG_BDJ | DBG_CRIT, "Couldn't find symbol JNI_CreateJavaVM.\n");
+        BD_DEBUG(DBG_BDJ | DBG_CRIT, "Couldn't find symbol JNI_CreateJavaVM.\n");
         return NULL;
     }
 
@@ -87,7 +87,7 @@ BDJAVA* bdj_open(const char *path, const char* start, void* bd, void* registers)
 
     if (result != JNI_OK || !bdjava->env) {
         free(bdjava);
-        DEBUG(DBG_BDJ | DBG_CRIT, "Failed to create new Java VM.\n");
+        BD_DEBUG(DBG_BDJ | DBG_CRIT, "Failed to create new Java VM.\n");
         return NULL;
     }
 
@@ -98,13 +98,13 @@ BDJAVA* bdj_open(const char *path, const char* start, void* bd, void* registers)
 
     if (!bdjo) {
         free(bdjava);
-        DEBUG(DBG_BDJ | DBG_CRIT, "Failed to load BDJO file.\n");
+        BD_DEBUG(DBG_BDJ | DBG_CRIT, "Failed to load BDJO file.\n");
         return NULL;
     }
 
     if (start_xlet(bdjava->env, path, bdjo, bdjava) == BDJ_ERROR) {
         free(bdjava);
-        DEBUG(DBG_BDJ | DBG_CRIT, "Failed to start BDJ program.\n");
+        BD_DEBUG(DBG_BDJ | DBG_CRIT, "Failed to start BDJ program.\n");
         return NULL;
     }
 
@@ -166,7 +166,7 @@ void* load_jvm()
 {
     const char* java_home = getenv("JAVA_HOME"); // FIXME: should probably search multiple directories
     if (java_home == NULL) {
-        DEBUG(DBG_BDJ | DBG_CRIT, "JAVA_HOME not set, can't find Java VM.\n");
+        BD_DEBUG(DBG_BDJ | DBG_CRIT, "JAVA_HOME not set, can't find Java VM.\n");
         return NULL;
     }
 
diff --git a/src/libbluray/bdj/bdjo_parser.c b/src/libbluray/bdj/bdjo_parser.c
index da751e1..94effb9 100644
--- a/src/libbluray/bdj/bdjo_parser.c
+++ b/src/libbluray/bdj/bdjo_parser.c
@@ -33,7 +33,7 @@
  */
 
 #define JNICHK(a) if((*env)->ExceptionOccurred(env)) { \
-    DEBUG(DBG_BDJ, "Exception occured\n"); \
+    BD_DEBUG(DBG_BDJ, "Exception occured\n"); \
     (*env)->ExceptionDescribe(env); \
     } if (!a) return NULL;
 
@@ -354,7 +354,7 @@ static jobject _parse_bdjo(JNIEnv* env, BITBUFFER* buf)
     bb_read_bytes(buf, magic, 4);
 
     if (strncmp((const char*) magic, "BDJO", 4) != 0) {
-        DEBUG(DBG_BDJ | DBG_CRIT, "Invalid magic number in BDJO.\n");
+        BD_DEBUG(DBG_BDJ | DBG_CRIT, "Invalid magic number in BDJO.\n");
         return NULL;
     }
 
@@ -362,10 +362,10 @@ static jobject _parse_bdjo(JNIEnv* env, BITBUFFER* buf)
     uint8_t version[4];
     bb_read_bytes(buf, version, 4);
     if (_get_version(version) == BDJ_ERROR) {
-        DEBUG(DBG_BDJ | DBG_CRIT, "Invalid version of BDJO.\n");
+        BD_DEBUG(DBG_BDJ | DBG_CRIT, "Invalid version of BDJO.\n");
         return NULL;
     }
-    DEBUG(DBG_BDJ, "[bdj] BDJO > Version: %.4s\n", version);
+    BD_DEBUG(DBG_BDJ, "[bdj] BDJO > Version: %.4s\n", version);
 
     // skip some unnecessary data
     bb_seek(buf, 8*0x28, SEEK_CUR);
@@ -397,7 +397,7 @@ jobject bdjo_read(JNIEnv* env, const char* file)
 {
     BD_FILE_H *handle = file_open(file, "rb");
     if (handle == NULL) {
-        DEBUG(DBG_BDJ | DBG_CRIT, "Failed to open bdjo file (%s)\n", file);
+        BD_DEBUG(DBG_BDJ | DBG_CRIT, "Failed to open bdjo file (%s)\n", file);
         return NULL;
     }
 
diff --git a/src/libbluray/bdnav/index_parse.c b/src/libbluray/bdnav/index_parse.c
index d1b05df..aa8f5b1 100644
--- a/src/libbluray/bdnav/index_parse.c
+++ b/src/libbluray/bdnav/index_parse.c
@@ -102,7 +102,7 @@ static int _parse_app_info(BITSTREAM *bs, INDX_APP_INFO *app_info)
     len = bs_read(bs, 32);
 
     if (len != 34) {
-        DEBUG(DBG_NAV, "index.bdmv app_info length is %d, expected 34 !\n", len);
+        BD_DEBUG(DBG_NAV, "index.bdmv app_info length is %d, expected 34 !\n", len);
     }
 
     bs_skip(bs, 1);
@@ -134,7 +134,7 @@ static int _parse_header(BITSTREAM *bs, int *index_start, int *extension_data_st
     if (sig1 != INDX_SIG1 ||
        (sig2 != INDX_SIG2A &&
         sig2 != INDX_SIG2B)) {
-     DEBUG(DBG_NAV | DBG_CRIT, "index.bdmv failed signature match: expected INDX0100 got %8.8s\n", bs->buf);
+     BD_DEBUG(DBG_NAV | DBG_CRIT, "index.bdmv failed signature match: expected INDX0100 got %8.8s\n", bs->buf);
      return 0;
     }
 
@@ -154,7 +154,7 @@ INDX_ROOT *indx_parse(const char *file_name)
 
     fp = file_open(file_name, "rb");
     if (!fp) {
-        DEBUG(DBG_NAV | DBG_CRIT, "indx_parse(): error opening %s\n", file_name);
+        BD_DEBUG(DBG_NAV | DBG_CRIT, "indx_parse(): error opening %s\n", file_name);
         X_FREE(index);
         return NULL;
     }
@@ -162,19 +162,19 @@ INDX_ROOT *indx_parse(const char *file_name)
     bs_init(&bs, fp);
 
     if (!_parse_header(&bs, &indexes_start, &extension_data_start)) {
-        DEBUG(DBG_NAV | DBG_CRIT, "index.bdmv: invalid header\n");
+        BD_DEBUG(DBG_NAV | DBG_CRIT, "index.bdmv: invalid header\n");
         goto error;
     }
 
     if (!_parse_app_info(&bs, &index->app_info)) {
-        DEBUG(DBG_NAV | DBG_CRIT, "index.bdmv: error parsing app info\n");
+        BD_DEBUG(DBG_NAV | DBG_CRIT, "index.bdmv: error parsing app info\n");
         goto error;
     }
 
     bs_seek_byte(&bs, indexes_start);
 
     if (!_parse_index(&bs, index)) {
-        DEBUG(DBG_NAV | DBG_CRIT, "index.bdmv: error parsing indexes\n");
+        BD_DEBUG(DBG_NAV | DBG_CRIT, "index.bdmv: error parsing indexes\n");
         goto error;
     }
 
diff --git a/src/libbluray/bdnav/meta_parse.c b/src/libbluray/bdnav/meta_parse.c
index e2ce935..c6ffeff 100644
--- a/src/libbluray/bdnav/meta_parse.c
+++ b/src/libbluray/bdnav/meta_parse.c
@@ -99,7 +99,7 @@ static void _findMetaXMLfiles(META_ROOT *meta, const char *device_path)
     path = str_printf("%s" DIR_SEP "BDMV" DIR_SEP "META" DIR_SEP "DL", device_path);
     dir = dir_open(path);
     if (dir == NULL) {
-        DEBUG(DBG_DIR, "Failed to open meta dir %s\n", path);
+        BD_DEBUG(DBG_DIR, "Failed to open meta dir %s\n", path);
         X_FREE(path);
         return;
     }
@@ -139,7 +139,7 @@ META_ROOT *meta_parse(const char *device_path)
 
         BD_FILE_H *handle = file_open(path, "rb");
         if (handle == NULL) {
-            DEBUG(DBG_DIR, "Failed to open meta file (%s)\n", path);
+            BD_DEBUG(DBG_DIR, "Failed to open meta file (%s)\n", path);
             continue;
         }
 
@@ -152,7 +152,7 @@ META_ROOT *meta_parse(const char *device_path)
             int64_t size_read = file_read(handle, data, length);
             doc = xmlReadMemory((char*)data, size_read, base, NULL, 0);
             if (doc == NULL) {
-                DEBUG(DBG_DIR, "Failed to parse %s\n", path);
+                BD_DEBUG(DBG_DIR, "Failed to parse %s\n", path);
                 continue;
             }
             xmlNode *root_element = NULL;
@@ -171,7 +171,7 @@ META_ROOT *meta_parse(const char *device_path)
     xmlCleanupParser();
     return root;
 #else
-    DEBUG(DBG_DIR, "configured without libxml2 - can't parse meta info\n");
+    BD_DEBUG(DBG_DIR, "configured without libxml2 - can't parse meta info\n");
     return NULL;
 #endif
 }
@@ -181,7 +181,7 @@ META_DL *meta_get(META_ROOT *meta_root, const char *language_code)
     unsigned i;
 
     if (meta_root == NULL || meta_root->dl_count == 0) {
-        DEBUG(DBG_DIR, "meta_get not possible, no info available!\n");
+        BD_DEBUG(DBG_DIR, "meta_get not possible, no info available!\n");
         return NULL;
     }
 
@@ -191,17 +191,17 @@ META_DL *meta_get(META_ROOT *meta_root, const char *language_code)
                 return &meta_root->dl_entries[i];
             }
         }
-        DEBUG(DBG_DIR, "requested disclib language '%s' not found\n", language_code);
+        BD_DEBUG(DBG_DIR, "requested disclib language '%s' not found\n", language_code);
     }
 
     for (i = 0; i < meta_root->dl_count; i++) {
         if (strcasecmp(DEFAULT_LANGUAGE, meta_root->dl_entries[i].language_code) == 0) {
-            DEBUG(DBG_DIR, "using default disclib language '"DEFAULT_LANGUAGE"'\n");
+            BD_DEBUG(DBG_DIR, "using default disclib language '"DEFAULT_LANGUAGE"'\n");
             return &meta_root->dl_entries[i];
         }
     }
 
-    DEBUG(DBG_DIR, "requested disclib language '%s' or default '"DEFAULT_LANGUAGE"' not found, using '%s' instead\n", language_code, meta_root->dl_entries[0].language_code);
+    BD_DEBUG(DBG_DIR, "requested disclib language '%s' or default '"DEFAULT_LANGUAGE"' not found, using '%s' instead\n", language_code, meta_root->dl_entries[0].language_code);
     return &meta_root->dl_entries[0];
 }
 
diff --git a/src/libbluray/bdnav/navigation.c b/src/libbluray/bdnav/navigation.c
index 2c33af3..1f6895a 100644
--- a/src/libbluray/bdnav/navigation.c
+++ b/src/libbluray/bdnav/navigation.c
@@ -123,12 +123,12 @@ NAV_TITLE_LIST* nav_get_title_list(const char *root, uint32_t flags)
     title_list = calloc(1, sizeof(NAV_TITLE_LIST));
     title_list->title_info = calloc(title_info_alloc, sizeof(NAV_TITLE_INFO));
 
-    DEBUG(DBG_NAV, "Root: %s:\n", root);
+    BD_DEBUG(DBG_NAV, "Root: %s:\n", root);
     path = str_printf("%s" DIR_SEP "BDMV" DIR_SEP "PLAYLIST", root);
 
     dir = dir_open(path);
     if (dir == NULL) {
-        DEBUG(DBG_NAV, "Failed to open dir: %s\n", path);
+        BD_DEBUG(DBG_NAV, "Failed to open dir: %s\n", path);
         X_FREE(path);
         X_FREE(title_list);
         return NULL;
@@ -214,7 +214,7 @@ char* nav_find_main_title(const char *root)
     int res;
     char longest[11];
 
-    DEBUG(DBG_NAV, "Root: %s:\n", root);
+    BD_DEBUG(DBG_NAV, "Root: %s:\n", root);
     path = str_printf("%s" DIR_SEP "BDMV" DIR_SEP "PLAYLIST", root);
 
     dir = dir_open(path);
@@ -454,7 +454,7 @@ NAV_TITLE* nav_title_open(const char *root, const char *playlist)
     title->angle = 0;
     title->pl = mpls_parse(path, 0);
     if (title->pl == NULL) {
-        DEBUG(DBG_NAV, "Fail: Playlist parse %s\n", path);
+        BD_DEBUG(DBG_NAV, "Fail: Playlist parse %s\n", path);
         X_FREE(title);
         X_FREE(path);
         return NULL;
diff --git a/src/libbluray/bdnav/sound_parse.c b/src/libbluray/bdnav/sound_parse.c
index 4f3e3bd..160d0b8 100644
--- a/src/libbluray/bdnav/sound_parse.c
+++ b/src/libbluray/bdnav/sound_parse.c
@@ -42,7 +42,7 @@ static int _bclk_parse_header(BITSTREAM *bs, uint32_t *data_start, uint32_t *ext
     if (sig1 != BCLK_SIG1 ||
        (sig2 != BCLK_SIG2A &&
         sig2 != BCLK_SIG2B)) {
-     DEBUG(DBG_NAV, "sound.bdmv failed signature match: expected BCLK0100 got %8.8s\n", bs->buf);
+     BD_DEBUG(DBG_NAV, "sound.bdmv failed signature match: expected BCLK0100 got %8.8s\n", bs->buf);
      return 0;
     }
 
@@ -57,19 +57,19 @@ static int _sound_parse_attributes(BITSTREAM *bs, SOUND_OBJECT *obj)
     int i;
 
     switch (i = bs_read(bs, 4)) {
-        default: DEBUG(DBG_NAV, "unknown channel configuration code %d\n", i);
+        default: BD_DEBUG(DBG_NAV, "unknown channel configuration code %d\n", i);
         case 1:  obj->num_channels = 1;
                  break;
         case 3:  obj->num_channels = 2;
                  break;
     };
     switch (i = bs_read(bs, 4)) {
-        default: DEBUG(DBG_NAV, "unknown sample rate code %d\n", i);
+        default: BD_DEBUG(DBG_NAV, "unknown sample rate code %d\n", i);
         case 1:  obj->sample_rate = 48000;
                  break;
     };
     switch (i = bs_read(bs, 2)) {
-        default: DEBUG(DBG_NAV, "unknown bits per sample code %d\n", i);
+        default: BD_DEBUG(DBG_NAV, "unknown bits per sample code %d\n", i);
         case 1:  obj->bits_per_sample = 16;
                  break;
     };
@@ -131,14 +131,14 @@ SOUND_DATA *sound_parse(const char *file_name)
 
     fp = file_open(file_name, "rb");
     if (!fp) {
-      DEBUG(DBG_NAV | DBG_CRIT, "error opening %s\n", file_name);
+      BD_DEBUG(DBG_NAV | DBG_CRIT, "error opening %s\n", file_name);
       return NULL;
     }
 
     bs_init(&bs, fp);
 
     if (!_bclk_parse_header(&bs, &data_start, &extension_data_start)) {
-        DEBUG(DBG_NAV | DBG_CRIT, "%s: invalid header\n", file_name);
+        BD_DEBUG(DBG_NAV | DBG_CRIT, "%s: invalid header\n", file_name);
         goto error;
     }
 
@@ -149,7 +149,7 @@ SOUND_DATA *sound_parse(const char *file_name)
     num_sounds = bs_read(&bs, 8);
 
     if (data_len < 1) {
-        DEBUG(DBG_NAV | DBG_CRIT, "%s: empty database\n", file_name);
+        BD_DEBUG(DBG_NAV | DBG_CRIT, "%s: empty database\n", file_name);
         goto error;
     }
 
@@ -161,7 +161,7 @@ SOUND_DATA *sound_parse(const char *file_name)
 
     for (i = 0; i < data->num_sounds; i++) {
         if (!_sound_parse_index(&bs, data_offsets + i, &data->sounds[i])) {
-            DEBUG(DBG_NAV | DBG_CRIT, "%s: error parsing sound %d attribues\n", file_name, i);
+            BD_DEBUG(DBG_NAV | DBG_CRIT, "%s: error parsing sound %d attribues\n", file_name, i);
             goto error;
         }
     }
@@ -173,7 +173,7 @@ SOUND_DATA *sound_parse(const char *file_name)
         bs_seek_byte(&bs, data_start + data_offsets[i]);
 
         if (!_sound_read_samples(&bs, &data->sounds[i])) {
-            DEBUG(DBG_NAV | DBG_CRIT, "%s: error reading samples for sound %d\n", file_name, i);
+            BD_DEBUG(DBG_NAV | DBG_CRIT, "%s: error reading samples for sound %d\n", file_name, i);
             goto error;
         }
     }
diff --git a/src/libbluray/bluray.c b/src/libbluray/bluray.c
index f1b55fe..dc831ff 100644
--- a/src/libbluray/bluray.c
+++ b/src/libbluray/bluray.c
@@ -202,7 +202,7 @@ static int _queue_event(BLURAY *bd, BD_EVENT ev)
             return 1;
         }
 
-        DEBUG(DBG_BLURAY|DBG_CRIT, "_queue_event(%d, %d): queue overflow !\n", ev.event, ev.param);
+        BD_DEBUG(DBG_BLURAY|DBG_CRIT, "_queue_event(%d, %d): queue overflow !\n", ev.event, ev.param);
     }
 
     return 0;
@@ -258,10 +258,10 @@ static int _open_m2ts(BLURAY *bd, BD_STREAM *st)
             return 1;
         }
 
-        DEBUG(DBG_BLURAY, "Clip %s empty! (%p)\n", f_name, bd);
+        BD_DEBUG(DBG_BLURAY, "Clip %s empty! (%p)\n", f_name, bd);
     }
 
-    DEBUG(DBG_BLURAY | DBG_CRIT, "Unable to open clip %s! (%p)\n",
+    BD_DEBUG(DBG_BLURAY | DBG_CRIT, "Unable to open clip %s! (%p)\n",
           f_name, bd);
 
     X_FREE(f_name);
@@ -273,7 +273,7 @@ static int _read_block(BLURAY *bd, BD_STREAM *st, uint8_t *buf)
     const int len = 6144;
 
     if (st->fp) {
-        DEBUG(DBG_STREAM, "Reading unit [%d bytes] at %"PRIu64"... (%p)\n",
+        BD_DEBUG(DBG_STREAM, "Reading unit [%d bytes] at %"PRIu64"... (%p)\n",
               len, st->clip_block_pos, bd);
 
         if (len + st->clip_block_pos <= st->clip_size) {
@@ -281,11 +281,11 @@ static int _read_block(BLURAY *bd, BD_STREAM *st, uint8_t *buf)
 
             if ((read_len = file_read(st->fp, buf, len))) {
                 if (read_len != len)
-                    DEBUG(DBG_STREAM | DBG_CRIT, "Read %d bytes at %"PRIu64" ; requested %d ! (%p)\n", read_len, st->clip_block_pos, len, bd);
+                    BD_DEBUG(DBG_STREAM | DBG_CRIT, "Read %d bytes at %"PRIu64" ; requested %d ! (%p)\n", read_len, st->clip_block_pos, len, bd);
 
                 if (bd->aacs && bd->libaacs_decrypt_unit) {
                     if (!bd->libaacs_decrypt_unit(bd->aacs, buf)) {
-                        DEBUG(DBG_AACS | DBG_CRIT, "Unable decrypt unit (AACS)! (%p)\n", bd);
+                        BD_DEBUG(DBG_AACS | DBG_CRIT, "Unable decrypt unit (AACS)! (%p)\n", bd);
 
                         return 0;
                     } // decrypt
@@ -299,7 +299,7 @@ static int _read_block(BLURAY *bd, BD_STREAM *st, uint8_t *buf)
                     numFixes = bd->bdplus_fixup(bd->bdplus, len, buf);
 #if 1
                     if (numFixes) {
-                        DEBUG(DBG_BDPLUS,
+                        BD_DEBUG(DBG_BDPLUS,
                               "BDPLUS did %u fixups\n", numFixes);
                     }
 #endif
@@ -308,28 +308,28 @@ static int _read_block(BLURAY *bd, BD_STREAM *st, uint8_t *buf)
 
                 /* Check TP_extra_header Copy_permission_indicator. If != 0, unit is still encrypted. */
                 if (buf[0] & 0xc0) {
-                    DEBUG(DBG_BLURAY | DBG_CRIT,
+                    BD_DEBUG(DBG_BLURAY | DBG_CRIT,
                           "TP header copy permission indicator != 0, unit is still encrypted? (%p)\n", bd);
                     _queue_event(bd, (BD_EVENT){BD_EVENT_ENCRYPTED, 0});
                     return 0;
                 }
 
-                DEBUG(DBG_STREAM, "Read unit OK! (%p)\n", bd);
+                BD_DEBUG(DBG_STREAM, "Read unit OK! (%p)\n", bd);
 
                 return 1;
             }
 
-            DEBUG(DBG_STREAM | DBG_CRIT, "Read %d bytes at %"PRIu64" failed ! (%p)\n", len, st->clip_block_pos, bd);
+            BD_DEBUG(DBG_STREAM | DBG_CRIT, "Read %d bytes at %"PRIu64" failed ! (%p)\n", len, st->clip_block_pos, bd);
 
             return 0;
         }
 
-        DEBUG(DBG_STREAM | DBG_CRIT, "Read past EOF ! (%p)\n", bd);
+        BD_DEBUG(DBG_STREAM | DBG_CRIT, "Read past EOF ! (%p)\n", bd);
 
         return 0;
     }
 
-    DEBUG(DBG_BLURAY, "No valid title selected! (%p)\n", bd);
+    BD_DEBUG(DBG_BLURAY, "No valid title selected! (%p)\n", bd);
 
     return 0;
 }
@@ -368,7 +368,7 @@ static int _preload_m2ts(BLURAY *bd, BD_PRELOAD *p)
 
     for (; buf < end; buf += 6144) {
         if (!_read_block(bd, &st, buf)) {
-            DEBUG(DBG_BLURAY|DBG_CRIT, "_preload_m2ts(): error loading %s at %"PRIu64"\n",
+            BD_DEBUG(DBG_BLURAY|DBG_CRIT, "_preload_m2ts(): error loading %s at %"PRIu64"\n",
                   st.clip->name, (uint64_t)(buf - p->buf));
             _close_m2ts(&st);
             _close_preload(p);
@@ -378,7 +378,7 @@ static int _preload_m2ts(BLURAY *bd, BD_PRELOAD *p)
 
     /* */
 
-    DEBUG(DBG_BLURAY, "_preload_m2ts(): loaded %"PRIu64" bytes from %s\n",
+    BD_DEBUG(DBG_BLURAY, "_preload_m2ts(): loaded %"PRIu64" bytes from %s\n",
           st.clip_size, st.clip->name);
 
     _close_m2ts(&st);
@@ -449,12 +449,12 @@ static int _libaacs_required(BLURAY *bd)
     if (fd) {
         file_close(fd);
 
-        DEBUG(DBG_BLURAY, "AACS/Unit_Key_RO.inf found. Disc seems to be AACS protected (%p)\n", bd);
+        BD_DEBUG(DBG_BLURAY, "AACS/Unit_Key_RO.inf found. Disc seems to be AACS protected (%p)\n", bd);
         bd->disc_info.aacs_detected = 1;
         return 1;
     }
 
-    DEBUG(DBG_BLURAY, "AACS/Unit_Key_RO.inf not found. No AACS protection (%p)\n", bd);
+    BD_DEBUG(DBG_BLURAY, "AACS/Unit_Key_RO.inf not found. No AACS protection (%p)\n", bd);
     bd->disc_info.aacs_detected = 0;
     return 0;
 }
@@ -469,22 +469,22 @@ static int _libaacs_load(BLURAY *bd)
     bd->disc_info.libaacs_detected = 0;
     if ((bd->h_libaacs = dl_dlopen("libaacs", "0"))) {
 
-        DEBUG(DBG_BLURAY, "Loading libaacs (%p)\n", bd->h_libaacs);
+        BD_DEBUG(DBG_BLURAY, "Loading libaacs (%p)\n", bd->h_libaacs);
 
         bd->libaacs_open         = dl_dlsym(bd->h_libaacs, "aacs_open");
         bd->libaacs_decrypt_unit = dl_dlsym(bd->h_libaacs, "aacs_decrypt_unit");
 
         if (bd->libaacs_open && bd->libaacs_decrypt_unit) {
-            DEBUG(DBG_BLURAY, "Loaded libaacs (%p)\n", bd->h_libaacs);
+            BD_DEBUG(DBG_BLURAY, "Loaded libaacs (%p)\n", bd->h_libaacs);
             bd->disc_info.libaacs_detected = 1;
             return 1;
 
         } else {
-            DEBUG(DBG_BLURAY, "libaacs dlsym failed! (%p)\n", bd->h_libaacs);
+            BD_DEBUG(DBG_BLURAY, "libaacs dlsym failed! (%p)\n", bd->h_libaacs);
         }
 
     } else {
-        DEBUG(DBG_BLURAY, "libaacs not found! (%p)\n", bd);
+        BD_DEBUG(DBG_BLURAY, "libaacs not found! (%p)\n", bd);
     }
 
     _libaacs_unload(bd);
@@ -492,7 +492,7 @@ static int _libaacs_load(BLURAY *bd)
     return 0;
 
 #else
-    DEBUG(DBG_BLURAY, "Using libaacs via normal linking\n");
+    BD_DEBUG(DBG_BLURAY, "Using libaacs via normal linking\n");
 
     bd->libaacs_open         = &aacs_open;
     bd->libaacs_decrypt_unit = &aacs_decrypt_unit;
@@ -519,12 +519,12 @@ static int _libaacs_open(BLURAY *bd, const char *keyfile_path)
     bd->aacs = bd->libaacs_open(bd->device_path, keyfile_path);
 
     if (bd->aacs) {
-        DEBUG(DBG_BLURAY, "Opened libaacs (%p)\n", bd->aacs);
+        BD_DEBUG(DBG_BLURAY, "Opened libaacs (%p)\n", bd->aacs);
         bd->disc_info.aacs_handled = 1;
         return 1;
     }
 
-    DEBUG(DBG_BLURAY, "aacs_open() failed!\n");
+    BD_DEBUG(DBG_BLURAY, "aacs_open() failed!\n");
     bd->disc_info.aacs_handled = 0;
 
     _libaacs_unload(bd);
@@ -539,14 +539,14 @@ static uint8_t *_libaacs_get_vid(BLURAY *bd)
         if (fptr) {
             return (uint8_t*)fptr(bd->aacs);
         }
-        DEBUG(DBG_BLURAY, "aacs_get_vid() dlsym failed! (%p)", bd);
+        BD_DEBUG(DBG_BLURAY, "aacs_get_vid() dlsym failed! (%p)", bd);
         return NULL;
 #else
         return aacs_get_vid(bd->aacs);
 #endif
     }
 
-    DEBUG(DBG_BLURAY, "_libaacs_get_vid(): libaacs not initialized! (%p)", bd);
+    BD_DEBUG(DBG_BLURAY, "_libaacs_get_vid(): libaacs not initialized! (%p)", bd);
     return NULL;
 }
 
@@ -586,19 +586,19 @@ static int _libbdplus_required(BLURAY *bd)
     if (fd) {
         file_close(fd);
 
-        DEBUG(DBG_BLURAY, "BDSVM/00000.svm found. Disc seems to be BD+ protected (%p)\n", bd);
+        BD_DEBUG(DBG_BLURAY, "BDSVM/00000.svm found. Disc seems to be BD+ protected (%p)\n", bd);
         bd->disc_info.bdplus_detected = 1;
         return 1;
     }
 
-    DEBUG(DBG_BLURAY, "BDSVM/00000.svm not found. No BD+ protection (%p)\n", bd);
+    BD_DEBUG(DBG_BLURAY, "BDSVM/00000.svm not found. No BD+ protection (%p)\n", bd);
     bd->disc_info.bdplus_detected = 0;
     return 0;
 }
 
 static int _libbdplus_load(BLURAY *bd)
 {
-    DEBUG(DBG_BDPLUS, "attempting to load libbdplus\n");
+    BD_DEBUG(DBG_BDPLUS, "attempting to load libbdplus\n");
 
 #ifdef DLOPEN_CRYPTO_LIBS
     if (bd->h_libbdplus) {
@@ -608,22 +608,22 @@ static int _libbdplus_load(BLURAY *bd)
     bd->disc_info.libbdplus_detected = 0;
     if ((bd->h_libbdplus = dl_dlopen("libbdplus", "0"))) {
 
-        DEBUG(DBG_BLURAY, "Loading libbdplus (%p)\n", bd->h_libbdplus);
+        BD_DEBUG(DBG_BLURAY, "Loading libbdplus (%p)\n", bd->h_libbdplus);
 
         bd->bdplus_init  = dl_dlsym(bd->h_libbdplus, "bdplus_init");
         bd->bdplus_seek  = dl_dlsym(bd->h_libbdplus, "bdplus_seek");
         bd->bdplus_fixup = dl_dlsym(bd->h_libbdplus, "bdplus_fixup");
 
         if (bd->bdplus_init && bd->bdplus_seek && bd->bdplus_fixup) {
-            DEBUG(DBG_BLURAY, "Loaded libbdplus (%p)\n", bd->h_libbdplus);
+            BD_DEBUG(DBG_BLURAY, "Loaded libbdplus (%p)\n", bd->h_libbdplus);
             bd->disc_info.libbdplus_detected = 1;
             return 1;
         }
 
-        DEBUG(DBG_BLURAY, "libbdplus dlsym failed! (%p)\n", bd->h_libbdplus);
+        BD_DEBUG(DBG_BLURAY, "libbdplus dlsym failed! (%p)\n", bd->h_libbdplus);
 
     } else {
-        DEBUG(DBG_BLURAY, "libbdplus not found! (%p)\n", bd);
+        BD_DEBUG(DBG_BLURAY, "libbdplus not found! (%p)\n", bd);
     }
 
     _libbdplus_unload(bd);
@@ -631,7 +631,7 @@ static int _libbdplus_load(BLURAY *bd)
     return 0;
 
 #else
-    DEBUG(DBG_BLURAY,"Using libbdplus via normal linking\n");
+    BD_DEBUG(DBG_BLURAY,"Using libbdplus via normal linking\n");
 
     bd->bdplus_init  = &bdplus_init;
     bd->bdplus_seek  = &bdplus_seek;
@@ -665,12 +665,12 @@ static int _libbdplus_open(BLURAY *bd, const char *keyfile_path)
     bd->bdplus = bd->bdplus_init(bd->device_path, keyfile_path, _libaacs_get_vid(bd) ?: vid);
 
     if (bd->bdplus) {
-        DEBUG(DBG_BLURAY,"libbdplus initialized\n");
+        BD_DEBUG(DBG_BLURAY,"libbdplus initialized\n");
         bd->disc_info.bdplus_handled = 1;
         return 1;
     }
 
-    DEBUG(DBG_BLURAY,"bdplus_init() failed\n");
+    BD_DEBUG(DBG_BLURAY,"bdplus_init() failed\n");
     bd->disc_info.bdplus_handled = 0;
 
     _libbdplus_unload(bd);
@@ -777,11 +777,11 @@ BLURAY *bd_open(const char* device_path, const char* keyfile_path)
 
         _fill_disc_info(bd);
 
-        DEBUG(DBG_BLURAY, "BLURAY initialized! (%p)\n", bd);
+        BD_DEBUG(DBG_BLURAY, "BLURAY initialized! (%p)\n", bd);
     } else {
         X_FREE(bd);
 
-        DEBUG(DBG_BLURAY | DBG_CRIT, "No device path provided!\n");
+        BD_DEBUG(DBG_BLURAY | DBG_CRIT, "No device path provided!\n");
     }
 
     return bd;
@@ -814,7 +814,7 @@ void bd_close(BLURAY *bd)
     X_FREE(bd->event_queue);
     X_FREE(bd->device_path);
 
-    DEBUG(DBG_BLURAY, "BLURAY destroyed! (%p)\n", bd);
+    BD_DEBUG(DBG_BLURAY, "BLURAY destroyed! (%p)\n", bd);
 
     X_FREE(bd);
 }
@@ -836,7 +836,7 @@ static int64_t _seek_internal(BLURAY *bd,
         bd->next_chapter_start = bd_chapter_pos(bd, current_chapter + 1);
         bd_psr_write(bd->regs, PSR_CHAPTER,  current_chapter + 1);
 
-        DEBUG(DBG_BLURAY, "Seek to %"PRIu64" (%p)\n",
+        BD_DEBUG(DBG_BLURAY, "Seek to %"PRIu64" (%p)\n",
               bd->s_pos, bd);
 
         if (bd->bdplus_seek && bd->bdplus) {
@@ -1034,7 +1034,7 @@ int bd_read(BLURAY *bd, unsigned char *buf, int len)
 
     if (st->fp) {
         out_len = 0;
-        DEBUG(DBG_STREAM, "Reading [%d bytes] at %"PRIu64"... (%p)\n", len, bd->s_pos, bd);
+        BD_DEBUG(DBG_STREAM, "Reading [%d bytes] at %"PRIu64"... (%p)\n", len, bd->s_pos, bd);
 
         while (len > 0) {
             uint32_t clip_pkt;
@@ -1095,7 +1095,7 @@ int bd_read(BLURAY *bd, unsigned char *buf, int len)
                     // find next clip
                     st->clip = nav_next_clip(bd->title, st->clip);
                     if (st->clip == NULL) {
-                        DEBUG(DBG_BLURAY|DBG_STREAM, "End of title (%p)\n", bd);
+                        BD_DEBUG(DBG_BLURAY|DBG_STREAM, "End of title (%p)\n", bd);
                         _queue_event(bd, (BD_EVENT){BD_EVENT_END_OF_TITLE, 0});
                         return 0;
                     }
@@ -1139,12 +1139,12 @@ int bd_read(BLURAY *bd, unsigned char *buf, int len)
             bd_psr_write(bd->regs, PSR_CHAPTER, current_chapter + 1);
         }
 
-        DEBUG(DBG_STREAM, "%d bytes read OK! (%p)\n", out_len, bd);
+        BD_DEBUG(DBG_STREAM, "%d bytes read OK! (%p)\n", out_len, bd);
 
         return out_len;
     }
 
-    DEBUG(DBG_STREAM | DBG_CRIT, "bd_read(): no valid title selected! (%p)\n", bd);
+    BD_DEBUG(DBG_STREAM | DBG_CRIT, "bd_read(): no valid title selected! (%p)\n", bd);
 
     return -1;
 }
@@ -1165,7 +1165,7 @@ static int _find_ig_stream(BLURAY *bd, uint16_t *pid, int *sub_path_idx)
         }
         *pid = pi->stn.ig[ig_stream].pid;
 
-        DEBUG(DBG_BLURAY, "_find_ig_stream(): current IG stream pid 0x%04x sub-path %d\n",
+        BD_DEBUG(DBG_BLURAY, "_find_ig_stream(): current IG stream pid 0x%04x sub-path %d\n",
               *pid, *sub_path_idx);
         return 1;
     }
@@ -1233,7 +1233,7 @@ static int _open_playlist(BLURAY *bd, const char *f_name)
 
     bd->title = nav_title_open(bd->device_path, f_name);
     if (bd->title == NULL) {
-        DEBUG(DBG_BLURAY | DBG_CRIT, "Unable to open title %s! (%p)\n",
+        BD_DEBUG(DBG_BLURAY | DBG_CRIT, "Unable to open title %s! (%p)\n",
               f_name, bd);
         return 0;
     }
@@ -1250,7 +1250,7 @@ static int _open_playlist(BLURAY *bd, const char *f_name)
     // Get the initial clip of the playlist
     bd->st0.clip = nav_next_clip(bd->title, NULL);
     if (_open_m2ts(bd, &bd->st0)) {
-        DEBUG(DBG_BLURAY, "Title %s selected! (%p)\n", f_name, bd);
+        BD_DEBUG(DBG_BLURAY, "Title %s selected! (%p)\n", f_name, bd);
 
         _preload_subpaths(bd);
 
@@ -1290,11 +1290,11 @@ int bd_select_title(BLURAY *bd, uint32_t title_idx)
 
     // Open the playlist
     if (bd->title_list == NULL) {
-        DEBUG(DBG_BLURAY, "Title list not yet read! (%p)\n", bd);
+        BD_DEBUG(DBG_BLURAY, "Title list not yet read! (%p)\n", bd);
         return 0;
     }
     if (bd->title_list->count <= title_idx) {
-        DEBUG(DBG_BLURAY, "Invalid title index %d! (%p)\n", title_idx, bd);
+        BD_DEBUG(DBG_BLURAY, "Invalid title index %d! (%p)\n", title_idx, bd);
         return 0;
     }
 
@@ -1314,7 +1314,7 @@ int bd_select_angle(BLURAY *bd, unsigned angle)
     unsigned orig_angle;
 
     if (bd->title == NULL) {
-        DEBUG(DBG_BLURAY, "Title not yet selected! (%p)\n", bd);
+        BD_DEBUG(DBG_BLURAY, "Title not yet selected! (%p)\n", bd);
         return 0;
     }
 
@@ -1329,7 +1329,7 @@ int bd_select_angle(BLURAY *bd, unsigned angle)
     bd_psr_write(bd->regs, PSR_ANGLE_NUMBER, bd->title->angle + 1);
 
     if (!_open_m2ts(bd, &bd->st0)) {
-        DEBUG(DBG_BLURAY|DBG_CRIT, "Error selecting angle %d ! (%p)\n", angle, bd);
+        BD_DEBUG(DBG_BLURAY|DBG_CRIT, "Error selecting angle %d ! (%p)\n", angle, bd);
         return 0;
     }
 
@@ -1363,7 +1363,7 @@ void bd_seamless_angle_change(BLURAY *bd, unsigned angle)
 uint32_t bd_get_titles(BLURAY *bd, uint8_t flags)
 {
     if (!bd) {
-        DEBUG(DBG_BLURAY | DBG_CRIT, "bd_get_titles(NULL) failed (%p)\n", bd);
+        BD_DEBUG(DBG_BLURAY | DBG_CRIT, "bd_get_titles(NULL) failed (%p)\n", bd);
         return 0;
     }
 
@@ -1373,7 +1373,7 @@ uint32_t bd_get_titles(BLURAY *bd, uint8_t flags)
     bd->title_list = nav_get_title_list(bd->device_path, flags);
 
     if (!bd->title_list) {
-        DEBUG(DBG_BLURAY | DBG_CRIT, "nav_get_title_list(%s) failed (%p)\n", bd->device_path, bd);
+        BD_DEBUG(DBG_BLURAY | DBG_CRIT, "nav_get_title_list(%s) failed (%p)\n", bd->device_path, bd);
         return 0;
     }
 
@@ -1453,7 +1453,7 @@ static BLURAY_TITLE_INFO *_get_title_info(BLURAY *bd, uint32_t title_idx, uint32
 
     title = nav_title_open(bd->device_path, mpls_name);
     if (title == NULL) {
-        DEBUG(DBG_BLURAY | DBG_CRIT, "Unable to open title %s! (%p)\n",
+        BD_DEBUG(DBG_BLURAY | DBG_CRIT, "Unable to open title %s! (%p)\n",
               mpls_name, bd);
         return NULL;
     }
@@ -1467,11 +1467,11 @@ static BLURAY_TITLE_INFO *_get_title_info(BLURAY *bd, uint32_t title_idx, uint32
 BLURAY_TITLE_INFO* bd_get_title_info(BLURAY *bd, uint32_t title_idx)
 {
     if (bd->title_list == NULL) {
-        DEBUG(DBG_BLURAY, "Title list not yet read! (%p)\n", bd);
+        BD_DEBUG(DBG_BLURAY, "Title list not yet read! (%p)\n", bd);
         return NULL;
     }
     if (bd->title_list->count <= title_idx) {
-        DEBUG(DBG_BLURAY, "Invalid title index %d! (%p)\n", title_idx, bd);
+        BD_DEBUG(DBG_BLURAY, "Invalid title index %d! (%p)\n", title_idx, bd);
         return NULL;
     }
 
@@ -1570,11 +1570,11 @@ int bd_start_bdj(BLURAY *bd, const char *start_object)
         bd->bdjava = bdj_open(bd->device_path, start_object, bd, bd->regs);
         return !!bd->bdjava;
     } else {
-        DEBUG(DBG_BLURAY | DBG_CRIT, "BD-J is already running (%p)\n", bd);
+        BD_DEBUG(DBG_BLURAY | DBG_CRIT, "BD-J is already running (%p)\n", bd);
         return 1;
     }
 #else
-    DEBUG(DBG_BLURAY | DBG_CRIT, "%s.bdjo: BD-J not compiled in (%p)\n", start_object, bd);
+    BD_DEBUG(DBG_BLURAY | DBG_CRIT, "%s.bdjo: BD-J not compiled in (%p)\n", start_object, bd);
 #endif
     return 0;
 }
@@ -1585,7 +1585,7 @@ void bd_stop_bdj(BLURAY *bd)
 #ifdef USING_BDJAVA
         bdj_close((BDJAVA*)bd->bdjava);
 #else
-        DEBUG(DBG_BLURAY, "BD-J not compiled in (%p)\n", bd);
+        BD_DEBUG(DBG_BLURAY, "BD-J not compiled in (%p)\n", bd);
 #endif
         bd->bdjava = NULL;
     }
@@ -1602,7 +1602,7 @@ static void _process_psr_event(void *handle, BD_PSR_EVENT *ev)
 {
     BLURAY *bd = (BLURAY*)handle;
 
-    DEBUG(DBG_BLURAY, "PSR event %d %d (%p)\n", ev->psr_idx, ev->new_val, bd);
+    BD_DEBUG(DBG_BLURAY, "PSR event %d %d (%p)\n", ev->psr_idx, ev->new_val, bd);
 
     switch (ev->psr_idx) {
 
@@ -1684,7 +1684,7 @@ static int _play_bdj(BLURAY *bd, const char *name)
     bd_stop_bdj(bd);
     return bd_start_bdj(bd, name);
 #else
-    DEBUG(DBG_BLURAY|DBG_CRIT, "_bdj_play(BDMV/BDJ/%s.jar) not implemented (%p)\n", name, bd);
+    BD_DEBUG(DBG_BLURAY|DBG_CRIT, "_bdj_play(BDMV/BDJ/%s.jar) not implemented (%p)\n", name, bd);
     return 0;
 #endif
 }
@@ -1736,7 +1736,7 @@ int bd_play_title(BLURAY *bd, unsigned title)
 
     /* bd_play not called ? */
     if (bd->title_type == title_undef) {
-        DEBUG(DBG_BLURAY|DBG_CRIT, "bd_call_title(): bd_play() not called !\n");
+        BD_DEBUG(DBG_BLURAY|DBG_CRIT, "bd_call_title(): bd_play() not called !\n");
         return 0;
     }
 
@@ -1826,7 +1826,7 @@ static void _run_gc(BLURAY *bd, gc_ctrl_e msg, uint32_t param)
 
 static void _process_hdmv_vm_event(BLURAY *bd, HDMV_EVENT *hev)
 {
-    DEBUG(DBG_BLURAY, "HDMV event: %d %d\n", hev->event, hev->param);
+    BD_DEBUG(DBG_BLURAY, "HDMV event: %d %d\n", hev->event, hev->param);
 
     switch (hev->event) {
         case HDMV_EVENT_TITLE:
@@ -1850,7 +1850,7 @@ static void _process_hdmv_vm_event(BLURAY *bd, HDMV_EVENT *hev)
             break;
 
         case HDMV_EVENT_PLAY_STOP:
-            DEBUG(DBG_BLURAY|DBG_CRIT, "HDMV_EVENT_PLAY_STOP: not tested !\n");
+            BD_DEBUG(DBG_BLURAY|DBG_CRIT, "HDMV_EVENT_PLAY_STOP: not tested !\n");
             // stop current playlist
             bd_seek(bd, (uint64_t)bd->title->packets * 192 - 1);
             bd->st0.clip = NULL;
@@ -1879,7 +1879,7 @@ static void _process_hdmv_vm_event(BLURAY *bd, HDMV_EVENT *hev)
             break;
 
         case HDMV_EVENT_IG_END:
-            DEBUG(DBG_BLURAY|DBG_CRIT, "HDMV_EVENT_IG_END\n");
+            BD_DEBUG(DBG_BLURAY|DBG_CRIT, "HDMV_EVENT_IG_END\n");
             _run_gc(bd, GC_CTRL_IG_END, 0);
             break;
 
@@ -1925,7 +1925,7 @@ int bd_read_ext(BLURAY *bd, unsigned char *buf, int len, BD_EVENT *event)
         while (!bd->hdmv_suspended) {
 
             if (_run_hdmv(bd) < 0) {
-                DEBUG(DBG_BLURAY|DBG_CRIT, "bd_read_ext(): HDMV VM error\n");
+                BD_DEBUG(DBG_BLURAY|DBG_CRIT, "bd_read_ext(): HDMV VM error\n");
                 bd->title_type = title_undef;
                 return -1;
             }
@@ -1948,7 +1948,7 @@ int bd_read_ext(BLURAY *bd, unsigned char *buf, int len, BD_EVENT *event)
         if (!bd->st0.clip && bd->title_type == title_hdmv) {
             hdmv_vm_resume(bd->hdmv_vm);
             bd->hdmv_suspended = !hdmv_vm_running(bd->hdmv_vm);
-            DEBUG(DBG_BLURAY, "bd_read_ext(): reached end of playlist. hdmv_suspended=%d\n", bd->hdmv_suspended);
+            BD_DEBUG(DBG_BLURAY, "bd_read_ext(): reached end of playlist. hdmv_suspended=%d\n", bd->hdmv_suspended);
         }
     }
 
diff --git a/src/libbluray/decoders/graphics_controller.c b/src/libbluray/decoders/graphics_controller.c
index 7035d68..71b0a8b 100644
--- a/src/libbluray/decoders/graphics_controller.c
+++ b/src/libbluray/decoders/graphics_controller.c
@@ -32,9 +32,6 @@
 
 #include <inttypes.h>
 
-#define ERROR(x,...) DEBUG(DBG_BLURAY | DBG_CRIT, x, ##__VA_ARGS__)
-#define TRACE(x,...) DEBUG(DBG_BLURAY,            x, ##__VA_ARGS__)
-
 /*
  *
  */
@@ -189,7 +186,7 @@ static uint16_t _find_selected_button_id(GRAPHICS_CONTROLLER *gc)
 
     page = _find_page(&s->ics->interactive_composition, page_id);
     if (!page) {
-        TRACE("_find_selected_button_id(): unknown page #%d (have %d pages)\n",
+        BD_TRACE("_find_selected_button_id(): unknown page #%d (have %d pages)\n",
               page_id, s->ics->interactive_composition.num_pages);
         return 0xffff;
     }
@@ -200,7 +197,7 @@ static uint16_t _find_selected_button_id(GRAPHICS_CONTROLLER *gc)
     if (_find_button_page(page, page->default_selected_button_id_ref, NULL) &&
         _is_button_enabled(gc, page, page->default_selected_button_id_ref)) {
 
-        TRACE("_find_selected_button_id() -> default #%d\n", page->default_selected_button_id_ref);
+        BD_TRACE("_find_selected_button_id() -> default #%d\n", page->default_selected_button_id_ref);
         return page->default_selected_button_id_ref;
     }
 
@@ -210,7 +207,7 @@ static uint16_t _find_selected_button_id(GRAPHICS_CONTROLLER *gc)
 
         if (button_id == gc->enabled_button[ii]) {
             if (_find_button_bog(bog, gc->enabled_button[ii])) {
-                TRACE("_find_selected_button_id() -> PSR10 #%d\n", gc->enabled_button[ii]);
+                BD_TRACE("_find_selected_button_id() -> PSR10 #%d\n", gc->enabled_button[ii]);
                 return gc->enabled_button[ii];
             }
         }
@@ -221,12 +218,12 @@ static uint16_t _find_selected_button_id(GRAPHICS_CONTROLLER *gc)
         BD_IG_BOG *bog = &page->bog[ii];
 
         if (_find_button_bog(bog, gc->enabled_button[ii])) {
-            TRACE("_find_selected_button_id() -> first valid #%d\n", gc->enabled_button[ii]);
+            BD_TRACE("_find_selected_button_id() -> first valid #%d\n", gc->enabled_button[ii]);
             return gc->enabled_button[ii];
         }
     }
 
-    TRACE("_find_selected_button_id(): not found -> 0xffff\n");
+    BD_TRACE("_find_selected_button_id(): not found -> 0xffff\n");
     return 0xffff;
 }
 
@@ -239,7 +236,7 @@ static void _reset_enabled_button(GRAPHICS_CONTROLLER *gc)
 
     page = _find_page(&s->ics->interactive_composition, page_id);
     if (!page) {
-        ERROR("_reset_enabled_button(): unknown page #%d (have %d pages)\n",
+        BD_ERROR("_reset_enabled_button(): unknown page #%d (have %d pages)\n",
               page_id, s->ics->interactive_composition.num_pages);
         return;
     }
@@ -344,7 +341,7 @@ void gc_free(GRAPHICS_CONTROLLER **p)
 void gc_decode_ts(GRAPHICS_CONTROLLER *gc, uint16_t pid, uint8_t *block, unsigned num_blocks, int64_t stc)
 {
     if (!gc) {
-        TRACE("gc_decode_ts(): no graphics controller\n");
+        BD_TRACE("gc_decode_ts(): no graphics controller\n");
         return;
     }
 
@@ -399,7 +396,7 @@ static void _render_button(GRAPHICS_CONTROLLER *gc, BD_IG_BUTTON *button, BD_PG_
 
     object = _find_object_for_button(gc->igs, button, state);
     if (!object) {
-        TRACE("_render_button(#%d): object (state %d) not found\n", button->id, state);
+        BD_TRACE("_render_button(#%d): object (state %d) not found\n", button->id, state);
         return;
     }
 
@@ -432,7 +429,7 @@ static void _render_page(GRAPHICS_CONTROLLER *gc,
     unsigned        selected_button_id = bd_psr_read(gc->regs, PSR_SELECTED_BUTTON_ID);
 
     if (s->ics->interactive_composition.ui_model == IG_UI_MODEL_POPUP && !gc->popup_visible) {
-        TRACE("_render_page(): popup menu not visible\n");
+        BD_TRACE("_render_page(): popup menu not visible\n");
 
         _clear_osd(gc, 1);
 
@@ -441,19 +438,19 @@ static void _render_page(GRAPHICS_CONTROLLER *gc,
 
     page = _find_page(&s->ics->interactive_composition, page_id);
     if (!page) {
-        ERROR("_render_page: unknown page id %d (have %d pages)\n",
+        BD_ERROR("_render_page: unknown page id %d (have %d pages)\n",
               page_id, s->ics->interactive_composition.num_pages);
         return;
     }
 
     palette = _find_palette(s, page->palette_id_ref);
     if (!palette) {
-        ERROR("_render_page: unknown palette id %d (have %d palettes)\n",
+        BD_ERROR("_render_page: unknown palette id %d (have %d palettes)\n",
               page->palette_id_ref, s->num_palette);
         return;
     }
 
-    TRACE("rendering page #%d using palette #%d. page has %d bogs\n",
+    BD_TRACE("rendering page #%d using palette #%d. page has %d bogs\n",
           page->id, page->palette_id_ref, page->num_bogs);
 
     for (ii = 0; ii < page->num_bogs; ii++) {
@@ -464,7 +461,7 @@ static void _render_page(GRAPHICS_CONTROLLER *gc,
         button = _find_button_bog(bog, valid_id);
 
         if (!button) {
-            TRACE("_render_page(): bog %d: button %d not found\n", ii, valid_id);
+            BD_TRACE("_render_page(): bog %d: button %d not found\n", ii, valid_id);
 
         } else if (button->id == activated_button_id) {
             _render_button(gc, button, palette, BTN_ACTIVATED);
@@ -505,26 +502,26 @@ static int _user_input(GRAPHICS_CONTROLLER *gc, bd_vk_key_e key, GC_NAV_CMDS *cm
     int             activated_btn_id = -1;
 
     if (s->ics->interactive_composition.ui_model == IG_UI_MODEL_POPUP && !gc->popup_visible) {
-        TRACE("_user_input(): popup menu not visible\n");
+        BD_TRACE("_user_input(): popup menu not visible\n");
         return -1;
     }
     if (!gc->ig_drawn) {
-        ERROR("_user_input(): menu not visible\n");
+        BD_ERROR("_user_input(): menu not visible\n");
         return -1;
     }
 
-    TRACE("_user_input(%d)\n", key);
+    BD_TRACE("_user_input(%d)\n", key);
 
     page = _find_page(&s->ics->interactive_composition, page_id);
     if (!page) {
-        ERROR("_user_input(): unknown page id %d (have %d pages)\n",
+        BD_ERROR("_user_input(): unknown page id %d (have %d pages)\n",
               page_id, s->ics->interactive_composition.num_pages);
         return -1;
     }
 
     if (key == BD_VK_MOUSE_ACTIVATE) {
         if (!gc->valid_mouse_position) {
-            TRACE("_user_input(): BD_VK_MOUSE_ACTIVATE outside of valid buttons\n");
+            BD_TRACE("_user_input(): BD_VK_MOUSE_ACTIVATE outside of valid buttons\n");
             return -1;
         }
         key = BD_VK_ENTER;
@@ -600,7 +597,7 @@ static void _set_button_page(GRAPHICS_CONTROLLER *gc, uint32_t param, GC_NAV_CMD
     BD_IG_PAGE     *page   = NULL;
     BD_IG_BUTTON   *button = NULL;
 
-    TRACE("_set_button_page(0x%08x): page flag %d, id %d, effects %d   button flag %d, id %d",
+    BD_TRACE("_set_button_page(0x%08x): page flag %d, id %d, effects %d   button flag %d, id %d",
           param, !!page_flag, page_id, !!effect_flag, !!button_flag, button_id);
 
     /* 10.4.3.4 (D) */
@@ -613,7 +610,7 @@ static void _set_button_page(GRAPHICS_CONTROLLER *gc, uint32_t param, GC_NAV_CMD
 
         /* current page --> command is ignored */
         if (page_id == bd_psr_read(gc->regs, PSR_MENU_PAGE_ID)) {
-            TRACE("  page is current\n");
+            BD_TRACE("  page is current\n");
             return;
         }
 
@@ -621,7 +618,7 @@ static void _set_button_page(GRAPHICS_CONTROLLER *gc, uint32_t param, GC_NAV_CMD
 
         /* invalid page --> command is ignored */
         if (!page) {
-            TRACE("  page is invalid\n");
+            BD_TRACE("  page is invalid\n");
             return;
         }
 
@@ -635,7 +632,7 @@ static void _set_button_page(GRAPHICS_CONTROLLER *gc, uint32_t param, GC_NAV_CMD
         page    = _find_page(&s->ics->interactive_composition, page_id);
 
         if (!page) {
-            ERROR("_set_button_page(): PSR_MENU_PAGE_ID refers to unknown page %d\n", page_id);
+            BD_ERROR("_set_button_page(): PSR_MENU_PAGE_ID refers to unknown page %d\n", page_id);
             return;
         }
     }
@@ -647,12 +644,12 @@ static void _set_button_page(GRAPHICS_CONTROLLER *gc, uint32_t param, GC_NAV_CMD
         if (!page_flag) {
             if (!button) {
                 /* page not given, invalid button --> ignore command */
-                TRACE("  button is invalid\n");
+                BD_TRACE("  button is invalid\n");
                 return;
             }
             if (button_id == bd_psr_read(gc->regs, PSR_SELECTED_BUTTON_ID)) {
                 /* page not given, current button --> ignore command */
-                TRACE("  button is current\n");
+                BD_TRACE("  button is current\n");
                 return;
             }
         }
@@ -675,11 +672,11 @@ static void _enable_button(GRAPHICS_CONTROLLER *gc, uint32_t button_id, unsigned
     unsigned        cur_btn_id = bd_psr_read(gc->regs, PSR_SELECTED_BUTTON_ID);
     unsigned        bog_idx    = 0;
 
-    TRACE("_enable_button(#%d, %s)\n", button_id, enable ? "enable" : "disable");
+    BD_TRACE("_enable_button(#%d, %s)\n", button_id, enable ? "enable" : "disable");
 
     page = _find_page(&s->ics->interactive_composition, page_id);
     if (!page) {
-        TRACE("_enable_button(): unknown page #%d (have %d pages)\n",
+        BD_TRACE("_enable_button(): unknown page #%d (have %d pages)\n",
               page_id, s->ics->interactive_composition.num_pages);
         return;
     }
@@ -687,7 +684,7 @@ static void _enable_button(GRAPHICS_CONTROLLER *gc, uint32_t button_id, unsigned
     /* find correct button overlap group */
     button = _find_button_page(page, button_id, &bog_idx);
     if (!button) {
-        TRACE("_enable_button(): unknown button #%d (page #%d)\n", button_id, page_id);
+        BD_TRACE("_enable_button(): unknown button #%d (page #%d)\n", button_id, page_id);
         return;
     }
 
@@ -714,13 +711,13 @@ static void _update_selected_button(GRAPHICS_CONTROLLER *gc)
     /* executed after IG command sequence terminates */
     unsigned button_id = bd_psr_read(gc->regs, PSR_SELECTED_BUTTON_ID);
 
-    TRACE("_update_selected_button(): currently enabled button is #%d\n", button_id);
+    BD_TRACE("_update_selected_button(): currently enabled button is #%d\n", button_id);
 
     /* special case: triggered only after enable button disables selected button */
     if (button_id & 0x10000) {
         button_id &= 0xffff;
         bd_psr_write(gc->regs, PSR_SELECTED_BUTTON_ID, button_id);
-        TRACE("_update_selected_button() -> #%d [last enabled]\n", button_id);
+        BD_TRACE("_update_selected_button() -> #%d [last enabled]\n", button_id);
         return;
     }
 
@@ -742,13 +739,13 @@ static int _mouse_move(GRAPHICS_CONTROLLER *gc, unsigned x, unsigned y, GC_NAV_C
     gc->valid_mouse_position = 0;
 
     if (!gc->ig_drawn) {
-        ERROR("_mouse_move(): menu not visible\n");
+        BD_ERROR("_mouse_move(): menu not visible\n");
         return -1;
     }
 
     page = _find_page(&s->ics->interactive_composition, page_id);
     if (!page) {
-        ERROR("_mouse_move(): unknown page #%d (have %d pages)\n",
+        BD_ERROR("_mouse_move(): unknown page #%d (have %d pages)\n",
               page_id, s->ics->interactive_composition.num_pages);
         return -1;
     }
@@ -804,7 +801,7 @@ int gc_run(GRAPHICS_CONTROLLER *gc, gc_ctrl_e ctrl, uint32_t param, GC_NAV_CMDS
     }
 
     if (!gc) {
-        TRACE("gc_run(): no graphics controller\n");
+        BD_TRACE("gc_run(): no graphics controller\n");
         return result;
     }
 
@@ -822,7 +819,7 @@ int gc_run(GRAPHICS_CONTROLLER *gc, gc_ctrl_e ctrl, uint32_t param, GC_NAV_CMDS
 
     /* other operations require complete display set */
     if (!gc->igs || !gc->igs->ics || !gc->igs->complete) {
-        TRACE("gc_run(): no interactive composition\n");
+        BD_TRACE("gc_run(): no interactive composition\n");
         bd_mutex_unlock(&gc->mutex);
         return result;
     }
diff --git a/src/libbluray/decoders/graphics_processor.c b/src/libbluray/decoders/graphics_processor.c
index 9f435db..d2192eb 100644
--- a/src/libbluray/decoders/graphics_processor.c
+++ b/src/libbluray/decoders/graphics_processor.c
@@ -32,10 +32,6 @@
 #include <stdlib.h>
 #include <inttypes.h>
 
-//#define ERROR(x,...)
-#define ERROR(x,...) DEBUG(DBG_BLURAY|DBG_CRIT,x,##__VA_ARGS__)
-#define TRACE(x...)  do {} while (0)
-
 
 /*
  * segment types
@@ -186,7 +182,7 @@ static int _decode_wds(PG_DISPLAY_SET *s, BITBUFFER *bb, PES_BUFFER *p)
     (void)bb;
     (void)p;
 
-    ERROR("unhandled segment type (PGS_WINDOW)\n");
+    BD_ERROR("unhandled segment type (PGS_WINDOW)\n");
     return 0;
 }
 
@@ -272,7 +268,7 @@ static int _decode_pcs(PG_DISPLAY_SET *s, BITBUFFER *bb, PES_BUFFER *p)
     (void)bb;
     (void)p;
 
-    ERROR("unhandled segment type (PGS_PG_COMPOSITION)\n");
+    BD_ERROR("unhandled segment type (PGS_PG_COMPOSITION)\n");
     return 0;
 }
 
@@ -338,7 +334,7 @@ static int _decode_segment(PG_DISPLAY_SET *s, PES_BUFFER *p)
             return 1;
 
         default:
-            ERROR("unknown segment type 0x%x\n", type);
+            BD_ERROR("unknown segment type 0x%x\n", type);
             break;
     }
 
@@ -365,18 +361,18 @@ int graphics_processor_decode_pes(PG_DISPLAY_SET **s, PES_BUFFER **p, int64_t st
 
         /* time to decode next segment ? */
         if (stc >= 0 && (*p)->dts > stc) {
-            TRACE("Segment dts > stc (%"PRId64" > %"PRId64" ; diff %"PRId64")\n",
+            BD_TRACE("Segment dts > stc (%"PRId64" > %"PRId64" ; diff %"PRId64")\n",
                   (*p)->dts, stc, (*p)->dts - stc);
             return 0;
         }
 
         /* all fragments present ? */
         if (!_join_segment_fragments(*p)) {
-            TRACE("splitted segment not complete, waiting for next fragment\n");
+            BD_TRACE("splitted segment not complete, waiting for next fragment\n");
             return 0;
         }
 
-        TRACE("Decoding segment, dts %010"PRId64" pts %010"PRId64" len %d\n",
+        BD_TRACE("Decoding segment, dts %010"PRId64" pts %010"PRId64" len %d\n",
               (*p)->dts, (*p)->pts, (*p)->len);
 
         /* decode segment */
diff --git a/src/libbluray/decoders/ig_decode.c b/src/libbluray/decoders/ig_decode.c
index ec2c1db..c432cf8 100644
--- a/src/libbluray/decoders/ig_decode.c
+++ b/src/libbluray/decoders/ig_decode.c
@@ -30,9 +30,6 @@
 #include <string.h>
 #include <stdlib.h>
 
-//#define ERROR(x,...)
-#define ERROR(x,...) DEBUG(DBG_BLURAY|DBG_CRIT,x,##__VA_ARGS__)
-
 
 static void _decode_button(BITBUFFER *bb, BD_IG_BUTTON *p)
 {
@@ -223,7 +220,7 @@ static int _decode_interactive_composition(BITBUFFER *bb, BD_IG_INTERACTIVE_COMP
     uint32_t data_len = bb_read(bb, 24);
     uint32_t buf_len  = bb->p_end - bb->p;
     if (data_len != buf_len) {
-        ERROR("ig_decode_interactive(): buffer size mismatch (expected %d, have %d)\n", data_len, buf_len);
+        BD_ERROR("ig_decode_interactive(): buffer size mismatch (expected %d, have %d)\n", data_len, buf_len);
         return 0;
     }
 
@@ -273,15 +270,15 @@ int ig_decode_interactive(BITBUFFER *bb, BD_IG_INTERACTIVE *p)
     pg_decode_sequence_descriptor(bb, &sd);
 
     if (!sd.first_in_seq) {
-        ERROR("ig_decode_interactive(): not first in seq\n");
+        BD_ERROR("ig_decode_interactive(): not first in seq\n");
         return 0;
     }
     if (!sd.last_in_seq) {
-        ERROR("ig_decode_interactive(): not last in seq\n");
+        BD_ERROR("ig_decode_interactive(): not last in seq\n");
         return 0;
     }
     if (!bb_is_align(bb, 0x07)) {
-        ERROR("ig_decode_interactive(): alignment error\n");
+        BD_ERROR("ig_decode_interactive(): alignment error\n");
         return 0;
     }
 
diff --git a/src/libbluray/decoders/m2ts_demux.c b/src/libbluray/decoders/m2ts_demux.c
index 3201e68..a0ef2d0 100644
--- a/src/libbluray/decoders/m2ts_demux.c
+++ b/src/libbluray/decoders/m2ts_demux.c
@@ -26,9 +26,6 @@
 #include <stdlib.h>
 #include <string.h>
 
-/*#define TRACE(x,...) DEBUG(DBG_CRIT,x,##__VA_ARGS__)*/
-#define TRACE(x,...) do {} while(0)
-
 /*
  *
  */
@@ -91,12 +88,12 @@ static int _add_ts(PES_BUFFER *p, unsigned pusi, uint8_t *buf, unsigned len)
         unsigned hdr_len    = buf[8] + 9;
 
         if (buf[0] || buf[1] || buf[2] != 1) {
-            TRACE("invalid PES header (00 00 01)");
+            BD_TRACE("invalid PES header (00 00 01)");
             return -1;
         }
 
         if (len < hdr_len) {
-            TRACE("invalid BDAV TS (PES header not in single TS packet)\n");
+            BD_TRACE("invalid BDAV TS (PES header not in single TS packet)\n");
             return -1;
         }
 
@@ -147,29 +144,29 @@ PES_BUFFER *m2ts_demux(M2TS_DEMUX *p, uint8_t *buf)
         int      payload_offset = (buf[4+3] & 0x20) ? buf[4+4] + 5 : 4;
 
         if (buf[4] != 0x47) {
-            DEBUG(DBG_BLURAY, "missing sync byte. scrambled data ?\n");
+            BD_DEBUG(DBG_BLURAY, "missing sync byte. scrambled data ?\n");
             return NULL;
         }
         if (pid != p->pid) {
-            TRACE("skipping packet (pid %d)\n", pid);
+            BD_TRACE("skipping packet (pid %d)\n", pid);
             continue;
         }
         if (tp_error) {
-            DEBUG(DBG_BLURAY, "skipping packet (transport error)\n");
+            BD_DEBUG(DBG_BLURAY, "skipping packet (transport error)\n");
             continue;
         }
         if (!payload_exists) {
-            TRACE("skipping packet (no payload)\n");
+            BD_TRACE("skipping packet (no payload)\n");
             continue;
         }
         if (payload_offset >= 188) {
-            DEBUG(DBG_BLURAY, "skipping packet (invalid payload start address)\n");
+            BD_DEBUG(DBG_BLURAY, "skipping packet (invalid payload start address)\n");
             continue;
         }
 
         if (pusi) {
             if (p->buf) {
-                DEBUG(DBG_BLURAY, "PES length mismatch: have %d, expected %d\n",
+                BD_DEBUG(DBG_BLURAY, "PES length mismatch: have %d, expected %d\n",
                       p->buf->len, p->pes_length);
                 pes_buffer_free(&p->buf);
             }
@@ -177,14 +174,14 @@ PES_BUFFER *m2ts_demux(M2TS_DEMUX *p, uint8_t *buf)
         }
 
         if (!p->buf) {
-            DEBUG(DBG_BLURAY, "skipping packet (no pusi seen)\n");
+            BD_DEBUG(DBG_BLURAY, "skipping packet (no pusi seen)\n");
             continue;
         }
 
         int r = _add_ts(p->buf, pusi, buf + 4 + payload_offset, 188 - payload_offset);
         if (r) {
             if (r < 0) {
-                DEBUG(DBG_BLURAY, "skipping block (PES header error)\n");
+                BD_DEBUG(DBG_BLURAY, "skipping block (PES header error)\n");
                 pes_buffer_free(&p->buf);
                 continue;
             }
@@ -192,7 +189,7 @@ PES_BUFFER *m2ts_demux(M2TS_DEMUX *p, uint8_t *buf)
         }
 
         if (p->buf->len == p->pes_length) {
-            TRACE("PES complete (%d bytes)\n", p->pes_length);
+            BD_TRACE("PES complete (%d bytes)\n", p->pes_length);
             pes_buffer_append(&result, p->buf);
             p->buf = NULL;
         }
diff --git a/src/libbluray/decoders/pg_decode.c b/src/libbluray/decoders/pg_decode.c
index 23cf704..e44691e 100644
--- a/src/libbluray/decoders/pg_decode.c
+++ b/src/libbluray/decoders/pg_decode.c
@@ -26,9 +26,6 @@
 #include <string.h>
 #include <stdlib.h>
 
-//#define ERROR(x,...)
-#define ERROR(x,...) DEBUG(DBG_BLURAY|DBG_CRIT,x,##__VA_ARGS__)
-
 
 void pg_decode_video_descriptor(BITBUFFER *bb, BD_PG_VIDEO_DESCRIPTOR *p)
 {
@@ -151,11 +148,11 @@ static int _decode_rle(BITBUFFER *bb, BD_PG_OBJECT *p)
     }
 
     if (pixels_left > 0) {
-        ERROR("pg_decode_object(): missing %d pixels\n", pixels_left);
+        BD_ERROR("pg_decode_object(): missing %d pixels\n", pixels_left);
         return 0;
     }
     if (pixels_left < 0) {
-        ERROR("pg_decode_object(): too many pixels (%d)\n", -pixels_left);
+        BD_ERROR("pg_decode_object(): too many pixels (%d)\n", -pixels_left);
         return 0;
     }
 
@@ -173,23 +170,23 @@ int pg_decode_object(BITBUFFER *bb, BD_PG_OBJECT *p)
 
     /* splitted segments should be already joined */
     if (!sd.first_in_seq) {
-        ERROR("pg_decode_object(): not first in sequence\n");
+        BD_ERROR("pg_decode_object(): not first in sequence\n");
         return 0;
     }
     if (!sd.last_in_seq) {
-        ERROR("pg_decode_object(): not last in sequence\n");
+        BD_ERROR("pg_decode_object(): not last in sequence\n");
         return 0;
     }
 
     if (!bb_is_align(bb, 0x07)) {
-      ERROR("pg_decode_object(): alignment error\n");
+      BD_ERROR("pg_decode_object(): alignment error\n");
       return 0;
     }
 
     uint32_t data_len = bb_read(bb, 24);
     uint32_t buf_len  = bb->p_end - bb->p;
     if (data_len != buf_len) {
-        ERROR("pg_decode_object(): buffer size mismatch (expected %d, have %d)\n", data_len, buf_len);
+        BD_ERROR("pg_decode_object(): buffer size mismatch (expected %d, have %d)\n", data_len, buf_len);
         return 0;
     }
 
diff --git a/src/libbluray/hdmv/hdmv_vm.c b/src/libbluray/hdmv/hdmv_vm.c
index 9b415e6..4fe38d1 100644
--- a/src/libbluray/hdmv/hdmv_vm.c
+++ b/src/libbluray/hdmv/hdmv_vm.c
@@ -83,12 +83,12 @@ static int _is_valid_reg(uint32_t reg)
 static int _store_reg(HDMV_VM *p, uint32_t reg, uint32_t val)
 {
     if (!_is_valid_reg(reg)) {
-        DEBUG(DBG_HDMV, "_store_reg(): invalid register 0x%x\n", reg);
+        BD_DEBUG(DBG_HDMV, "_store_reg(): invalid register 0x%x\n", reg);
         return -1;
     }
 
     if (reg & PSR_FLAG) {
-        DEBUG(DBG_HDMV, "_store_reg(): storing to PSR is not allowed\n");
+        BD_DEBUG(DBG_HDMV, "_store_reg(): storing to PSR is not allowed\n");
         return -1;
     }  else {
         return bd_gpr_write(p->regs, reg, val);
@@ -98,7 +98,7 @@ static int _store_reg(HDMV_VM *p, uint32_t reg, uint32_t val)
 static uint32_t _read_reg(HDMV_VM *p, uint32_t reg)
 {
     if (!_is_valid_reg(reg)) {
-        DEBUG(DBG_HDMV, "_read_reg(): invalid register 0x%x\n", reg);
+        BD_DEBUG(DBG_HDMV, "_read_reg(): invalid register 0x%x\n", reg);
         return 0;
     }
 
@@ -138,7 +138,7 @@ static int _store_result(HDMV_VM *p, MOBJ_CMD *cmd, uint32_t src, uint32_t dst,
     /* store result to destination register(s) */
     if (dst != dst0) {
         if (cmd->insn.imm_op1) {
-            DEBUG(DBG_HDMV|DBG_CRIT, "ERROR: storing to imm ! ");
+            BD_DEBUG(DBG_HDMV|DBG_CRIT, "BD_ERROR: storing to imm ! ");
             return -1;
         }
         ret = _store_reg(p, cmd->dst, dst);
@@ -146,7 +146,7 @@ static int _store_result(HDMV_VM *p, MOBJ_CMD *cmd, uint32_t src, uint32_t dst,
 
     if (src != src0) {
         if (cmd->insn.imm_op1) {
-            DEBUG(DBG_HDMV|DBG_CRIT, "ERROR: storing to imm ! ");
+            BD_DEBUG(DBG_HDMV|DBG_CRIT, "BD_ERROR: storing to imm ! ");
             return -1;
         }
         ret += _store_reg(p, cmd->src, src);
@@ -223,7 +223,7 @@ static int _queue_event(HDMV_VM *p, uint32_t event, uint32_t param)
         }
     }
 
-    DEBUG(DBG_HDMV|DBG_CRIT, "_queue_event(%d, %d): queue overflow !\n", event, param);
+    BD_DEBUG(DBG_HDMV|DBG_CRIT, "_queue_event(%d, %d): queue overflow !\n", event, param);
     return -1;
 }
 
@@ -280,10 +280,10 @@ void hdmv_vm_free(HDMV_VM **p)
 
 static void _suspend_object(HDMV_VM *p)
 {
-    DEBUG(DBG_HDMV, "_suspend_object()\n");
+    BD_DEBUG(DBG_HDMV, "_suspend_object()\n");
 
     if (p->suspended_object) {
-        DEBUG(DBG_HDMV, "_suspend_object: object already suspended !\n");
+        BD_DEBUG(DBG_HDMV, "_suspend_object: object already suspended !\n");
         // [execute the call, discard old suspended object (10.2.4.2.2)].
     }
 
@@ -298,7 +298,7 @@ static void _suspend_object(HDMV_VM *p)
 static int _resume_object(HDMV_VM *p)
 {
     if (!p->suspended_object) {
-        DEBUG(DBG_HDMV|DBG_CRIT, "_resume_object: no suspended object!\n");
+        BD_DEBUG(DBG_HDMV|DBG_CRIT, "_resume_object: no suspended object!\n");
         return -1;
     }
 
@@ -307,7 +307,7 @@ static int _resume_object(HDMV_VM *p)
 
     bd_psr_restore_state(p->regs);
 
-    DEBUG(DBG_HDMV, "resuming object %p at %d\n", p->object, p->pc + 1);
+    BD_DEBUG(DBG_HDMV, "resuming object %p at %d\n", p->object, p->pc + 1);
 
     p->suspended_object = NULL;
 
@@ -322,11 +322,11 @@ static int _resume_object(HDMV_VM *p)
 static int _jump_object(HDMV_VM *p, int object)
 {
     if (object < 0 || object >= p->movie_objects->num_objects) {
-        DEBUG(DBG_HDMV|DBG_CRIT, "_jump_object(): invalid object %d\n", object);
+        BD_DEBUG(DBG_HDMV|DBG_CRIT, "_jump_object(): invalid object %d\n", object);
         return -1;
     }
 
-    DEBUG(DBG_HDMV, "_jump_object(): jumping to object %d\n", object);
+    BD_DEBUG(DBG_HDMV, "_jump_object(): jumping to object %d\n", object);
 
     _free_ig_object(p);
 
@@ -339,7 +339,7 @@ static int _jump_object(HDMV_VM *p, int object)
 static int _jump_title(HDMV_VM *p, int title)
 {
     if (title >= 0 && title <= 0xffff) {
-        DEBUG(DBG_HDMV, "_jump_title(%d)\n", title);
+        BD_DEBUG(DBG_HDMV, "_jump_title(%d)\n", title);
 
         if (p->suspended_object) {
             /* discard suspended object */
@@ -351,14 +351,14 @@ static int _jump_title(HDMV_VM *p, int title)
         return 0;
     }
 
-    DEBUG(DBG_HDMV|DBG_CRIT, "_jump_title(%d): invalid title number\n", title);
+    BD_DEBUG(DBG_HDMV|DBG_CRIT, "_jump_title(%d): invalid title number\n", title);
 
     return -1;
 }
 
 static int _call_object(HDMV_VM *p, int object)
 {
-    DEBUG(DBG_HDMV, "_call_object(%d)\n", object);
+    BD_DEBUG(DBG_HDMV, "_call_object(%d)\n", object);
 
     _suspend_object(p);
 
@@ -368,7 +368,7 @@ static int _call_object(HDMV_VM *p, int object)
 static int _call_title(HDMV_VM *p, int title)
 {
     if (title >= 0 && title <= 0xffff) {
-        DEBUG(DBG_HDMV, "_call_title(%d)\n", title);
+        BD_DEBUG(DBG_HDMV, "_call_title(%d)\n", title);
 
         _suspend_object(p);
 
@@ -376,7 +376,7 @@ static int _call_title(HDMV_VM *p, int title)
         return 0;
     }
 
-    DEBUG(DBG_HDMV|DBG_CRIT, "_call_title(%d): invalid title number\n", title);
+    BD_DEBUG(DBG_HDMV|DBG_CRIT, "_call_title(%d): invalid title number\n", title);
 
     return -1;
 }
@@ -388,20 +388,20 @@ static int _call_title(HDMV_VM *p, int title)
 static int _play_at(HDMV_VM *p, int playlist, int playitem, int playmark)
 {
     if (p->ig_object && playlist >= 0) {
-        DEBUG(DBG_HDMV, "play_at(list %d, item %d, mark %d): "
+        BD_DEBUG(DBG_HDMV, "play_at(list %d, item %d, mark %d): "
               "playlist change not allowed in interactive composition\n",
               playlist, playitem, playmark);
         return -1;
     }
 
     if (!p->ig_object && playlist < 0) {
-        DEBUG(DBG_HDMV, "play_at(list %d, item %d, mark %d): "
+        BD_DEBUG(DBG_HDMV, "play_at(list %d, item %d, mark %d): "
               "playlist not given in movie object (link commands not allowed)\n",
               playlist, playitem, playmark);
         return -1;
     }
 
-    DEBUG(DBG_HDMV, "play_at(list %d, item %d, mark %d)\n",
+    BD_DEBUG(DBG_HDMV, "play_at(list %d, item %d, mark %d)\n",
           playlist, playitem, playmark);
 
     if (playlist >= 0) {
@@ -423,11 +423,11 @@ static int _play_at(HDMV_VM *p, int playlist, int playitem, int playmark)
 static int _play_stop(HDMV_VM *p)
 {
     if (!p->ig_object) {
-        DEBUG(DBG_HDMV, "_play_stop() not allowed in movie object\n");
+        BD_DEBUG(DBG_HDMV, "_play_stop() not allowed in movie object\n");
         return -1;
     }
 
-    DEBUG(DBG_HDMV, "_play_stop()\n");
+    BD_DEBUG(DBG_HDMV, "_play_stop()\n");
     _queue_event(p, HDMV_EVENT_PLAY_STOP, 0);
     return 0;
 }
@@ -438,7 +438,7 @@ static int _play_stop(HDMV_VM *p)
 
 static void _set_stream(HDMV_VM *p, uint32_t dst, uint32_t src)
 {
-    DEBUG(DBG_HDMV, "_set_stream(0x%x, 0x%x)\n", dst, src);
+    BD_DEBUG(DBG_HDMV, "_set_stream(0x%x, 0x%x)\n", dst, src);
 
     /* primary audio stream */
     if (dst & 0x80000000) {
@@ -478,7 +478,7 @@ static void _set_stream(HDMV_VM *p, uint32_t dst, uint32_t src)
 
 static void _set_sec_stream(HDMV_VM *p, uint32_t dst, uint32_t src)
 {
-    DEBUG(DBG_HDMV, "_set_sec_stream(0x%x, 0x%x)\n", dst, src);
+    BD_DEBUG(DBG_HDMV, "_set_sec_stream(0x%x, 0x%x)\n", dst, src);
 
     uint32_t disp_v_flag   = (dst >> 30) & 1;
     uint32_t disp_a_flag   = (src >> 30) & 1;
@@ -610,11 +610,11 @@ static void _set_nv_timer(HDMV_VM *p, uint32_t dst, uint32_t src)
 
   /* validate params */
   if (mobj_id >= p->movie_objects->num_objects) {
-      DEBUG(DBG_HDMV|DBG_CRIT, "_set_nv_timer(): invalid object id (%d) !\n", mobj_id);
+      BD_DEBUG(DBG_HDMV|DBG_CRIT, "_set_nv_timer(): invalid object id (%d) !\n", mobj_id);
       return;
   }
   if (timeout > 300) {
-      DEBUG(DBG_HDMV|DBG_CRIT, "_set_nv_timer(): invalid timeout (%d) !\n", timeout);
+      BD_DEBUG(DBG_HDMV|DBG_CRIT, "_set_nv_timer(): invalid timeout (%d) !\n", timeout);
       return;
   }
 
@@ -639,7 +639,7 @@ static int _check_nv_timer(HDMV_VM *p)
             ( now.tv_sec  == p->nv_timer.time.tv_sec &&
               now.tv_usec >= p->nv_timer.time.tv_usec)) {
 
-            DEBUG(DBG_HDMV, "navigation timer expired, jumping to object %d\n", p->nv_timer.mobj_id);
+            BD_DEBUG(DBG_HDMV, "navigation timer expired, jumping to object %d\n", p->nv_timer.mobj_id);
 
             bd_psr_write(p->regs, PSR_NAV_TIMER, 0);
 
@@ -673,7 +673,7 @@ static void _hdmv_trace_cmd(int pc, MOBJ_CMD *cmd)
 
         dst += mobj_sprint_cmd(dst, cmd);
 
-        DEBUG(DBG_HDMV, "%s\n", buf);
+        BD_DEBUG(DBG_HDMV, "%s\n", buf);
     }
 }
 
@@ -693,7 +693,7 @@ static void _hdmv_trace_res(uint32_t new_src, uint32_t new_dst, uint32_t orig_sr
             }
             dst += sprintf(dst, "]");
 
-            DEBUG(DBG_HDMV, "%s\n", buf);
+            BD_DEBUG(DBG_HDMV, "%s\n", buf);
         }
     }
 }
@@ -751,20 +751,20 @@ static int _hdmv_step(HDMV_VM *p)
             switch (insn->sub_grp) {
                 case BRANCH_GOTO:
                     if (insn->op_cnt > 1) {
-                        DEBUG(DBG_HDMV|DBG_CRIT, "[too many operands in BRANCH/GOTO opcode 0x%08x] ", *(uint32_t*)insn);
+                        BD_DEBUG(DBG_HDMV|DBG_CRIT, "[too many operands in BRANCH/GOTO opcode 0x%08x] ", *(uint32_t*)insn);
                     }
                     switch (insn->branch_opt) {
                         case INSN_NOP:                      break;
                         case INSN_GOTO:  p->pc   = dst - 1; break;
                         case INSN_BREAK: p->pc   = 1 << 17; break;
                         default:
-                            DEBUG(DBG_HDMV|DBG_CRIT, "[unknown BRANCH/GOTO option in opcode 0x%08x] ", *(uint32_t*)insn);
+                            BD_DEBUG(DBG_HDMV|DBG_CRIT, "[unknown BRANCH/GOTO option in opcode 0x%08x] ", *(uint32_t*)insn);
                             break;
                     }
                     break;
                 case BRANCH_JUMP:
                     if (insn->op_cnt > 1) {
-                        DEBUG(DBG_HDMV|DBG_CRIT, "[too many operands in BRANCH/JUMP opcode 0x%08x] ", *(uint32_t*)insn);
+                        BD_DEBUG(DBG_HDMV|DBG_CRIT, "[too many operands in BRANCH/JUMP opcode 0x%08x] ", *(uint32_t*)insn);
                     }
                     switch (insn->branch_opt) {
                         case INSN_JUMP_TITLE:  _jump_title(p, dst); break;
@@ -773,7 +773,7 @@ static int _hdmv_step(HDMV_VM *p)
                         case INSN_JUMP_OBJECT: if (!_jump_object(p, dst)) { inc_pc = 0; } break;
                         case INSN_CALL_OBJECT: if (!_call_object(p, dst)) { inc_pc = 0; } break;
                         default:
-                            DEBUG(DBG_HDMV|DBG_CRIT, "[unknown BRANCH/JUMP option in opcode 0x%08x] ", *(uint32_t*)insn);
+                            BD_DEBUG(DBG_HDMV|DBG_CRIT, "[unknown BRANCH/JUMP option in opcode 0x%08x] ", *(uint32_t*)insn);
                             break;
                     }
                     break;
@@ -786,20 +786,20 @@ static int _hdmv_step(HDMV_VM *p)
                         case INSN_LINK_PI:      _play_at(p,  -1, dst,  -1); break;
                         case INSN_LINK_MK:      _play_at(p,  -1,  -1, dst); break;
                         default:
-                            DEBUG(DBG_HDMV|DBG_CRIT, "[unknown BRANCH/PLAY option in opcode 0x%08x] ", *(uint32_t*)insn);
+                            BD_DEBUG(DBG_HDMV|DBG_CRIT, "[unknown BRANCH/PLAY option in opcode 0x%08x] ", *(uint32_t*)insn);
                             break;
                     }
                     break;
 
                 default:
-                    DEBUG(DBG_HDMV|DBG_CRIT, "[unknown BRANCH subgroup in opcode 0x%08x] ", *(uint32_t*)insn);
+                    BD_DEBUG(DBG_HDMV|DBG_CRIT, "[unknown BRANCH subgroup in opcode 0x%08x] ", *(uint32_t*)insn);
                     break;
             }
             break; /* INSN_GROUP_BRANCH */
 
         case INSN_GROUP_CMP:
             if (insn->op_cnt < 2) {
-                DEBUG(DBG_HDMV|DBG_CRIT, "missing operand in BRANCH/JUMP opcode 0x%08x] ", *(uint32_t*)insn);
+                BD_DEBUG(DBG_HDMV|DBG_CRIT, "missing operand in BRANCH/JUMP opcode 0x%08x] ", *(uint32_t*)insn);
             }
             switch (insn->cmp_opt) {
                 case INSN_BC: p->pc += !(dst &  src); break;
@@ -810,7 +810,7 @@ static int _hdmv_step(HDMV_VM *p)
                 case INSN_LE: p->pc += !(dst <= src); break;
                 case INSN_LT: p->pc += !(dst <  src); break;
                 default:
-                    DEBUG(DBG_HDMV|DBG_CRIT, "[unknown COMPARE option in opcode 0x%08x] ", *(uint32_t*)insn);
+                    BD_DEBUG(DBG_HDMV|DBG_CRIT, "[unknown COMPARE option in opcode 0x%08x] ", *(uint32_t*)insn);
                     break;
             }
             break; /* INSN_GROUP_CMP */
@@ -822,7 +822,7 @@ static int _hdmv_step(HDMV_VM *p)
                     uint32_t dst0 = dst;
 
                     if (insn->op_cnt < 2) {
-                        DEBUG(DBG_HDMV|DBG_CRIT, "missing operand in SET/SET opcode 0x%08x] ", *(uint32_t*)insn);
+                        BD_DEBUG(DBG_HDMV|DBG_CRIT, "missing operand in SET/SET opcode 0x%08x] ", *(uint32_t*)insn);
                     }
                     switch (insn->set_opt) {
                         case INSN_MOVE:   dst  = src;         break;
@@ -841,7 +841,7 @@ static int _hdmv_step(HDMV_VM *p)
                         case INSN_SHL:    dst <<= src;        break;
                         case INSN_SHR:    dst >>= src;        break;
                         default:
-                            DEBUG(DBG_HDMV|DBG_CRIT, "[unknown SET option in opcode 0x%08x] ", *(uint32_t*)insn);
+                            BD_DEBUG(DBG_HDMV|DBG_CRIT, "[unknown SET option in opcode 0x%08x] ", *(uint32_t*)insn);
                             break;
                     }
 
@@ -866,18 +866,18 @@ static int _hdmv_step(HDMV_VM *p)
                         case INSN_STILL_ON:        _set_still_mode (p,   1);      break;
                         case INSN_STILL_OFF:       _set_still_mode (p,   0);      break;
                         default:
-                            DEBUG(DBG_HDMV|DBG_CRIT, "[unknown SETSYSTEM option in opcode 0x%08x] ", *(uint32_t*)insn);
+                            BD_DEBUG(DBG_HDMV|DBG_CRIT, "[unknown SETSYSTEM option in opcode 0x%08x] ", *(uint32_t*)insn);
                             break;
                     }
                     break;
                 default:
-                    DEBUG(DBG_HDMV|DBG_CRIT, "[unknown SET subgroup in opcode 0x%08x] ", *(uint32_t*)insn);
+                    BD_DEBUG(DBG_HDMV|DBG_CRIT, "[unknown SET subgroup in opcode 0x%08x] ", *(uint32_t*)insn);
                     break;
             }
             break; /* INSN_GROUP_SET */
 
         default:
-            DEBUG(DBG_HDMV|DBG_CRIT, "[unknown group in opcode 0x%08x] ", *(uint32_t*)insn);
+            BD_DEBUG(DBG_HDMV|DBG_CRIT, "[unknown group in opcode 0x%08x] ", *(uint32_t*)insn);
             break;
     }
 
@@ -990,7 +990,7 @@ static int _vm_run(HDMV_VM *p, HDMV_EVENT *ev)
 
     /* valid program ? */
     if (!p->object) {
-        DEBUG(DBG_HDMV|DBG_CRIT, "hdmv_vm_run(): no object selected\n");
+        BD_DEBUG(DBG_HDMV|DBG_CRIT, "hdmv_vm_run(): no object selected\n");
         return -1;
     }
 
@@ -998,7 +998,7 @@ static int _vm_run(HDMV_VM *p, HDMV_EVENT *ev)
 
         /* terminated ? */
         if (p->pc >= p->object->num_cmds) {
-            DEBUG(DBG_HDMV, "terminated with PC=%d\n", p->pc);
+            BD_DEBUG(DBG_HDMV, "terminated with PC=%d\n", p->pc);
             p->object = NULL;
             ev->event = HDMV_EVENT_END;
 
@@ -1022,7 +1022,7 @@ static int _vm_run(HDMV_VM *p, HDMV_EVENT *ev)
         }
     }
 
-    DEBUG(DBG_HDMV|DBG_CRIT, "hdmv_vm: infinite program ? terminated after %d instructions.\n", MAX_LOOP);
+    BD_DEBUG(DBG_HDMV|DBG_CRIT, "hdmv_vm: infinite program ? terminated after %d instructions.\n", MAX_LOOP);
     p->object = NULL;
     return -1;
 }
diff --git a/src/libbluray/hdmv/mobj_parse.c b/src/libbluray/hdmv/mobj_parse.c
index 5a42ff4..0b01d05 100644
--- a/src/libbluray/hdmv/mobj_parse.c
+++ b/src/libbluray/hdmv/mobj_parse.c
@@ -41,7 +41,7 @@ static int _mobj_parse_header(BITSTREAM *bs, int *extension_data_start)
     if (sig1 != MOBJ_SIG1 ||
        (sig2 != MOBJ_SIG2A &&
         sig2 != MOBJ_SIG2B)) {
-     DEBUG(DBG_NAV, "MovieObject.bdmv failed signature match: expected MOBJ0100 got %8.8s\n", bs->buf);
+     BD_DEBUG(DBG_NAV, "MovieObject.bdmv failed signature match: expected MOBJ0100 got %8.8s\n", bs->buf);
      return 0;
     }
 
@@ -120,14 +120,14 @@ MOBJ_OBJECTS *mobj_parse(const char *file_name)
 
     fp = file_open(file_name, "rb");
     if (!fp) {
-      DEBUG(DBG_NAV | DBG_CRIT, "error opening %s\n", file_name);
+      BD_DEBUG(DBG_NAV | DBG_CRIT, "error opening %s\n", file_name);
       return NULL;
     }
 
     bs_init(&bs, fp);
 
     if (!_mobj_parse_header(&bs, &extension_data_start)) {
-        DEBUG(DBG_NAV | DBG_CRIT, "%s: invalid header\n", file_name);
+        BD_DEBUG(DBG_NAV | DBG_CRIT, "%s: invalid header\n", file_name);
         goto error;
     }
 
@@ -142,7 +142,7 @@ MOBJ_OBJECTS *mobj_parse(const char *file_name)
 
     for (i = 0; i < objects->num_objects; i++) {
         if (!_mobj_parse_object(&bs, &objects->objects[i])) {
-            DEBUG(DBG_NAV | DBG_CRIT, "%s: error parsing object %d\n", file_name, i);
+            BD_DEBUG(DBG_NAV | DBG_CRIT, "%s: error parsing object %d\n", file_name, i);
             goto error;
         }
     }
diff --git a/src/libbluray/register.c b/src/libbluray/register.c
index aa469d3..a4b97ea 100644
--- a/src/libbluray/register.c
+++ b/src/libbluray/register.c
@@ -303,7 +303,7 @@ void bd_psr_restore_state(BD_REGISTERS *p)
 int bd_gpr_write(BD_REGISTERS *p, int reg, uint32_t val)
 {
     if (reg < 0 || reg > BD_GPR_COUNT) {
-        DEBUG(DBG_BLURAY, "bd_gpr_write(%d): invalid register\n", reg);
+        BD_DEBUG(DBG_BLURAY, "bd_gpr_write(%d): invalid register\n", reg);
         return -1;
     }
 
@@ -314,7 +314,7 @@ int bd_gpr_write(BD_REGISTERS *p, int reg, uint32_t val)
 uint32_t bd_gpr_read(BD_REGISTERS *p, int reg)
 {
     if (reg < 0 || reg > BD_GPR_COUNT) {
-        DEBUG(DBG_BLURAY, "bd_gpr_read(%d): invalid register\n", reg);
+        BD_DEBUG(DBG_BLURAY, "bd_gpr_read(%d): invalid register\n", reg);
         return -1;
     }
 
@@ -330,7 +330,7 @@ uint32_t bd_psr_read(BD_REGISTERS *p, int reg)
     uint32_t val;
 
     if (reg < 0 || reg > BD_PSR_COUNT) {
-        DEBUG(DBG_BLURAY, "bd_psr_read(%d): invalid register\n", reg);
+        BD_DEBUG(DBG_BLURAY, "bd_psr_read(%d): invalid register\n", reg);
         return -1;
     }
 
@@ -346,21 +346,21 @@ uint32_t bd_psr_read(BD_REGISTERS *p, int reg)
 int bd_psr_setting_write(BD_REGISTERS *p, int reg, uint32_t val)
 {
     if (reg < 0 || reg > BD_PSR_COUNT) {
-        DEBUG(DBG_BLURAY, "bd_psr_write(%d, %d): invalid register\n", reg, val);
+        BD_DEBUG(DBG_BLURAY, "bd_psr_write(%d, %d): invalid register\n", reg, val);
         return -1;
     }
 
     if (p->psr[reg] == val) {
-        DEBUG(DBG_BLURAY, "bd_psr_write(%d, %d): no change in value\n", reg, val);
+        BD_DEBUG(DBG_BLURAY, "bd_psr_write(%d, %d): no change in value\n", reg, val);
         return 0;
     }
 
     bd_psr_lock(p);
 
     if (bd_psr_name[reg]) {
-        DEBUG(DBG_BLURAY, "bd_psr_write(): PSR%-4d (%s) 0x%x -> 0x%x\n", reg, bd_psr_name[reg], p->psr[reg], val);
+        BD_DEBUG(DBG_BLURAY, "bd_psr_write(): PSR%-4d (%s) 0x%x -> 0x%x\n", reg, bd_psr_name[reg], p->psr[reg], val);
     } else {
-        DEBUG(DBG_BLURAY, "bd_psr_write(): PSR%-4d 0x%x -> 0x%x\n", reg, p->psr[reg], val);
+        BD_DEBUG(DBG_BLURAY, "bd_psr_write(): PSR%-4d 0x%x -> 0x%x\n", reg, p->psr[reg], val);
     }
 
     if (p->num_cb) {
@@ -394,7 +394,7 @@ int bd_psr_write(BD_REGISTERS *p, int reg, uint32_t val)
         (reg >= 15 && reg <= 20) ||
         (reg >= 29 && reg <= 31) ||
         (reg >= 48 && reg <= 61)) {
-      DEBUG(DBG_BLURAY, "bd_psr_write(%d, %d): read-only register !\n", reg, val);
+      BD_DEBUG(DBG_BLURAY, "bd_psr_write(%d, %d): read-only register !\n", reg, val);
       return -2;
   }
 
diff --git a/src/util/logging.c b/src/util/logging.c
index ee50acd..b48462f 100644
--- a/src/util/logging.c
+++ b/src/util/logging.c
@@ -64,11 +64,11 @@ void bd_debug(const char *file, int line, uint32_t mask, const char *format, ...
         logfile = stderr;
 
         char *env = NULL;
-        if ((env = getenv("BD_DEBUG_MASK")))
+        if ((env = getenv("DEBUG_MASK")))
             debug_mask = strtol(env, NULL, 0);
 
         // Send DEBUG to file?
-        if ((env = getenv("BD_DEBUG_FILE"))) {
+        if ((env = getenv("DEBUG_FILE"))) {
             logfile = fopen(env, "wb");
             setvbuf(logfile, NULL, _IOLBF, 0);
         }
diff --git a/src/util/logging.h b/src/util/logging.h
index d5132bc..45c9867 100644
--- a/src/util/logging.h
+++ b/src/util/logging.h
@@ -27,7 +27,15 @@
 
 #include <stdint.h>
 
-#define DEBUG(X,Y,...) bd_debug(__FILE__,__LINE__,X,Y,##__VA_ARGS__)
+#ifdef __INTEL_COMPILER
+#define BD_DEBUG(X,Y,...) bd_debug(__FILE__,__LINE__,X,Y,#__VA_ARGS__)
+#define BD_ERROR(x,...) BD_DEBUG(DBG_BLURAY | DBG_CRIT, x, #__VA_ARGS__)
+#define BD_TRACE(x,...) BD_DEBUG(DBG_BLURAY,            x, #__VA_ARGS__)
+#else	//	#ifdef __INTEL_COMPILER
+#define BD_DEBUG(X,Y,...) bd_debug(__FILE__,__LINE__,X,Y,##__VA_ARGS__)
+#define BD_ERROR(x,...) BD_DEBUG(DBG_BLURAY | DBG_CRIT, x, ##__VA_ARGS__)
+#define BD_TRACE(x,...) BD_DEBUG(DBG_BLURAY,            x, ##__VA_ARGS__)
+#endif	//	#ifdef __INTEL_COMPILER
 
 
 BD_PRIVATE char *print_hex(char *out, const uint8_t *str, int count);
diff --git a/src/util/mutex.h b/src/util/mutex.h
index 0e2adc7..2aa03e4 100644
--- a/src/util/mutex.h
+++ b/src/util/mutex.h
@@ -74,7 +74,7 @@ static inline int bd_mutex_init(BD_MUTEX *p)
     p->lock_count = 0;
 
     if (pthread_mutex_init(&p->mutex, NULL)) {
-        DEBUG(DBG_BLURAY|DBG_CRIT, "bd_mutex_init() failed !");
+        BD_DEBUG(DBG_BLURAY|DBG_CRIT, "bd_mutex_init() failed !");
         return -1;
     }
 
@@ -84,7 +84,7 @@ static inline int bd_mutex_init(BD_MUTEX *p)
 static inline int bd_mutex_destroy(BD_MUTEX *p)
 {
     if (pthread_mutex_destroy(&p->mutex)) {
-        DEBUG(DBG_BLURAY|DBG_CRIT, "bd_mutex_destroy() failed !");
+        BD_DEBUG(DBG_BLURAY|DBG_CRIT, "bd_mutex_destroy() failed !");
         return -1;
     }
     return 0;
@@ -99,7 +99,7 @@ static int bd_mutex_lock(BD_MUTEX *p)
     }
 
     if (pthread_mutex_lock(&p->mutex)) {
-        DEBUG(DBG_BLURAY|DBG_CRIT, "bd_mutex_lock() failed !");
+        BD_DEBUG(DBG_BLURAY|DBG_CRIT, "bd_mutex_lock() failed !");
         return -1;
     }
 
@@ -112,7 +112,7 @@ static int bd_mutex_lock(BD_MUTEX *p)
 static int bd_mutex_unlock(BD_MUTEX *p)
 {
     if (!pthread_equal(p->owner, pthread_self())) {
-        DEBUG(DBG_BLURAY|DBG_CRIT, "bd_mutex_unlock(): not owner !");
+        BD_DEBUG(DBG_BLURAY|DBG_CRIT, "bd_mutex_unlock(): not owner !");
         return -1;
     }
 
@@ -126,7 +126,7 @@ static int bd_mutex_unlock(BD_MUTEX *p)
     p->owner = (pthread_t)-1;
 
     if (pthread_mutex_unlock(&p->mutex)) {
-        DEBUG(DBG_BLURAY|DBG_CRIT, "bd_mutex_unlock() failed !");
+        BD_DEBUG(DBG_BLURAY|DBG_CRIT, "bd_mutex_unlock() failed !");
         return -1;
     }
 
-- 
1.7.0.2.msysgit.0

